/*******************************************************************************
* File Name: DELAY1A.h
* Version 3.30
*
* Description:
*  Contains the prototypes and constants for the functions available to the
*  PWM user module.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
********************************************************************************/

#if !defined(CY_PWM_DELAY1A_H)
#define CY_PWM_DELAY1A_H

#include "cytypes.h"
#include "cyfitter.h"
#include "CyLib.h" /* For CyEnterCriticalSection() and CyExitCriticalSection() functions */

extern uint8 DELAY1A_initVar;


/***************************************
* Conditional Compilation Parameters
***************************************/
#define DELAY1A_Resolution                     (8u)
#define DELAY1A_UsingFixedFunction             (0u)
#define DELAY1A_DeadBandMode                   (0u)
#define DELAY1A_KillModeMinTime                (0u)
#define DELAY1A_KillMode                       (0u)
#define DELAY1A_PWMMode                        (0u)
#define DELAY1A_PWMModeIsCenterAligned         (0u)
#define DELAY1A_DeadBandUsed                   (0u)
#define DELAY1A_DeadBand2_4                    (0u)

#if !defined(DELAY1A_PWMUDB_genblk8_stsreg__REMOVED)
    #define DELAY1A_UseStatus                  (0u)
#else
    #define DELAY1A_UseStatus                  (0u)
#endif /* !defined(DELAY1A_PWMUDB_genblk8_stsreg__REMOVED) */

#if !defined(DELAY1A_PWMUDB_genblk1_ctrlreg__REMOVED)
    #define DELAY1A_UseControl                 (1u)
#else
    #define DELAY1A_UseControl                 (0u)
#endif /* !defined(DELAY1A_PWMUDB_genblk1_ctrlreg__REMOVED) */

#define DELAY1A_UseOneCompareMode              (1u)
#define DELAY1A_MinimumKillTime                (1u)
#define DELAY1A_EnableMode                     (0u)

#define DELAY1A_CompareMode1SW                 (0u)
#define DELAY1A_CompareMode2SW                 (0u)

/* Check to see if required defines such as CY_PSOC5LP are available */
/* They are defined starting with cy_boot v3.0 */
#if !defined (CY_PSOC5LP)
    #error Component PWM_v3_30 requires cy_boot v3.0 or later
#endif /* (CY_ PSOC5LP) */

/* Use Kill Mode Enumerated Types */
#define DELAY1A__B_PWM__DISABLED 0
#define DELAY1A__B_PWM__ASYNCHRONOUS 1
#define DELAY1A__B_PWM__SINGLECYCLE 2
#define DELAY1A__B_PWM__LATCHED 3
#define DELAY1A__B_PWM__MINTIME 4


/* Use Dead Band Mode Enumerated Types */
#define DELAY1A__B_PWM__DBMDISABLED 0
#define DELAY1A__B_PWM__DBM_2_4_CLOCKS 1
#define DELAY1A__B_PWM__DBM_256_CLOCKS 2


/* Used PWM Mode Enumerated Types */
#define DELAY1A__B_PWM__ONE_OUTPUT 0
#define DELAY1A__B_PWM__TWO_OUTPUTS 1
#define DELAY1A__B_PWM__DUAL_EDGE 2
#define DELAY1A__B_PWM__CENTER_ALIGN 3
#define DELAY1A__B_PWM__DITHER 5
#define DELAY1A__B_PWM__HARDWARESELECT 4


/* Used PWM Compare Mode Enumerated Types */
#define DELAY1A__B_PWM__LESS_THAN 1
#define DELAY1A__B_PWM__LESS_THAN_OR_EQUAL 2
#define DELAY1A__B_PWM__GREATER_THAN 3
#define DELAY1A__B_PWM__GREATER_THAN_OR_EQUAL_TO 4
#define DELAY1A__B_PWM__EQUAL 0
#define DELAY1A__B_PWM__FIRMWARE 5



/***************************************
* Data Struct Definition
***************************************/


/**************************************************************************
 * Sleep Wakeup Backup structure for PWM Component
 *************************************************************************/
typedef struct
{

    uint8 PWMEnableState;

    #if(!DELAY1A_UsingFixedFunction)
        uint8 PWMUdb;               /* PWM Current Counter value  */
        #if(!DELAY1A_PWMModeIsCenterAligned)
            uint8 PWMPeriod;
        #endif /* (!DELAY1A_PWMModeIsCenterAligned) */
        #if (DELAY1A_UseStatus)
            uint8 InterruptMaskValue;   /* PWM Current Interrupt Mask */
        #endif /* (DELAY1A_UseStatus) */

        /* Backup for Deadband parameters */
        #if(DELAY1A_DeadBandMode == DELAY1A__B_PWM__DBM_256_CLOCKS || \
            DELAY1A_DeadBandMode == DELAY1A__B_PWM__DBM_2_4_CLOCKS)
            uint8 PWMdeadBandValue; /* Dead Band Counter Current Value */
        #endif /* deadband count is either 2-4 clocks or 256 clocks */

        /* Backup Kill Mode Counter*/
        #if(DELAY1A_KillModeMinTime)
            uint8 PWMKillCounterPeriod; /* Kill Mode period value */
        #endif /* (DELAY1A_KillModeMinTime) */

        /* Backup control register */
        #if(DELAY1A_UseControl)
            uint8 PWMControlRegister; /* PWM Control Register value */
        #endif /* (DELAY1A_UseControl) */

    #endif /* (!DELAY1A_UsingFixedFunction) */

}DELAY1A_backupStruct;


/***************************************
*        Function Prototypes
 **************************************/

void    DELAY1A_Start(void) ;
void    DELAY1A_Stop(void) ;

#if (DELAY1A_UseStatus || DELAY1A_UsingFixedFunction)
    void  DELAY1A_SetInterruptMode(uint8 interruptMode) ;
    uint8 DELAY1A_ReadStatusRegister(void) ;
#endif /* (DELAY1A_UseStatus || DELAY1A_UsingFixedFunction) */

#define DELAY1A_GetInterruptSource() DELAY1A_ReadStatusRegister()

#if (DELAY1A_UseControl)
    uint8 DELAY1A_ReadControlRegister(void) ;
    void  DELAY1A_WriteControlRegister(uint8 control)
          ;
#endif /* (DELAY1A_UseControl) */

#if (DELAY1A_UseOneCompareMode)
   #if (DELAY1A_CompareMode1SW)
       void    DELAY1A_SetCompareMode(uint8 comparemode)
               ;
   #endif /* (DELAY1A_CompareMode1SW) */
#else
    #if (DELAY1A_CompareMode1SW)
        void    DELAY1A_SetCompareMode1(uint8 comparemode)
                ;
    #endif /* (DELAY1A_CompareMode1SW) */
    #if (DELAY1A_CompareMode2SW)
        void    DELAY1A_SetCompareMode2(uint8 comparemode)
                ;
    #endif /* (DELAY1A_CompareMode2SW) */
#endif /* (DELAY1A_UseOneCompareMode) */

#if (!DELAY1A_UsingFixedFunction)
    uint8   DELAY1A_ReadCounter(void) ;
    uint8 DELAY1A_ReadCapture(void) ;

    #if (DELAY1A_UseStatus)
            void DELAY1A_ClearFIFO(void) ;
    #endif /* (DELAY1A_UseStatus) */

    void    DELAY1A_WriteCounter(uint8 counter)
            ;
#endif /* (!DELAY1A_UsingFixedFunction) */

void    DELAY1A_WritePeriod(uint8 period)
        ;
uint8 DELAY1A_ReadPeriod(void) ;

#if (DELAY1A_UseOneCompareMode)
    void    DELAY1A_WriteCompare(uint8 compare)
            ;
    uint8 DELAY1A_ReadCompare(void) ;
#else
    void    DELAY1A_WriteCompare1(uint8 compare)
            ;
    uint8 DELAY1A_ReadCompare1(void) ;
    void    DELAY1A_WriteCompare2(uint8 compare)
            ;
    uint8 DELAY1A_ReadCompare2(void) ;
#endif /* (DELAY1A_UseOneCompareMode) */


#if (DELAY1A_DeadBandUsed)
    void    DELAY1A_WriteDeadTime(uint8 deadtime) ;
    uint8   DELAY1A_ReadDeadTime(void) ;
#endif /* (DELAY1A_DeadBandUsed) */

#if ( DELAY1A_KillModeMinTime)
    void DELAY1A_WriteKillTime(uint8 killtime) ;
    uint8 DELAY1A_ReadKillTime(void) ;
#endif /* ( DELAY1A_KillModeMinTime) */

void DELAY1A_Init(void) ;
void DELAY1A_Enable(void) ;
void DELAY1A_Sleep(void) ;
void DELAY1A_Wakeup(void) ;
void DELAY1A_SaveConfig(void) ;
void DELAY1A_RestoreConfig(void) ;


/***************************************
*         Initialization Values
**************************************/
#define DELAY1A_INIT_PERIOD_VALUE          (255u)
#define DELAY1A_INIT_COMPARE_VALUE1        (200u)
#define DELAY1A_INIT_COMPARE_VALUE2        (63u)
#define DELAY1A_INIT_INTERRUPTS_MODE       (uint8)(((uint8)(0u <<   \
                                                    DELAY1A_STATUS_TC_INT_EN_MASK_SHIFT)) | \
                                                    (uint8)((uint8)(0u <<  \
                                                    DELAY1A_STATUS_CMP2_INT_EN_MASK_SHIFT)) | \
                                                    (uint8)((uint8)(0u <<  \
                                                    DELAY1A_STATUS_CMP1_INT_EN_MASK_SHIFT )) | \
                                                    (uint8)((uint8)(0u <<  \
                                                    DELAY1A_STATUS_KILL_INT_EN_MASK_SHIFT )))
#define DELAY1A_DEFAULT_COMPARE2_MODE      (uint8)((uint8)1u <<  DELAY1A_CTRL_CMPMODE2_SHIFT)
#define DELAY1A_DEFAULT_COMPARE1_MODE      (uint8)((uint8)1u <<  DELAY1A_CTRL_CMPMODE1_SHIFT)
#define DELAY1A_INIT_DEAD_TIME             (1u)


/********************************
*         Registers
******************************** */

#if (DELAY1A_UsingFixedFunction)
   #define DELAY1A_PERIOD_LSB              (*(reg16 *) DELAY1A_PWMHW__PER0)
   #define DELAY1A_PERIOD_LSB_PTR          ( (reg16 *) DELAY1A_PWMHW__PER0)
   #define DELAY1A_COMPARE1_LSB            (*(reg16 *) DELAY1A_PWMHW__CNT_CMP0)
   #define DELAY1A_COMPARE1_LSB_PTR        ( (reg16 *) DELAY1A_PWMHW__CNT_CMP0)
   #define DELAY1A_COMPARE2_LSB            (0x00u)
   #define DELAY1A_COMPARE2_LSB_PTR        (0x00u)
   #define DELAY1A_COUNTER_LSB             (*(reg16 *) DELAY1A_PWMHW__CNT_CMP0)
   #define DELAY1A_COUNTER_LSB_PTR         ( (reg16 *) DELAY1A_PWMHW__CNT_CMP0)
   #define DELAY1A_CAPTURE_LSB             (*(reg16 *) DELAY1A_PWMHW__CAP0)
   #define DELAY1A_CAPTURE_LSB_PTR         ( (reg16 *) DELAY1A_PWMHW__CAP0)
   #define DELAY1A_RT1                     (*(reg8 *)  DELAY1A_PWMHW__RT1)
   #define DELAY1A_RT1_PTR                 ( (reg8 *)  DELAY1A_PWMHW__RT1)

#else
   #if (DELAY1A_Resolution == 8u) /* 8bit - PWM */

       #if(DELAY1A_PWMModeIsCenterAligned)
           #define DELAY1A_PERIOD_LSB      (*(reg8 *)  DELAY1A_PWMUDB_sP8_pwmdp_u0__D1_REG)
           #define DELAY1A_PERIOD_LSB_PTR  ((reg8 *)   DELAY1A_PWMUDB_sP8_pwmdp_u0__D1_REG)
       #else
           #define DELAY1A_PERIOD_LSB      (*(reg8 *)  DELAY1A_PWMUDB_sP8_pwmdp_u0__F0_REG)
           #define DELAY1A_PERIOD_LSB_PTR  ((reg8 *)   DELAY1A_PWMUDB_sP8_pwmdp_u0__F0_REG)
       #endif /* (DELAY1A_PWMModeIsCenterAligned) */

       #define DELAY1A_COMPARE1_LSB        (*(reg8 *)  DELAY1A_PWMUDB_sP8_pwmdp_u0__D0_REG)
       #define DELAY1A_COMPARE1_LSB_PTR    ((reg8 *)   DELAY1A_PWMUDB_sP8_pwmdp_u0__D0_REG)
       #define DELAY1A_COMPARE2_LSB        (*(reg8 *)  DELAY1A_PWMUDB_sP8_pwmdp_u0__D1_REG)
       #define DELAY1A_COMPARE2_LSB_PTR    ((reg8 *)   DELAY1A_PWMUDB_sP8_pwmdp_u0__D1_REG)
       #define DELAY1A_COUNTERCAP_LSB      (*(reg8 *)  DELAY1A_PWMUDB_sP8_pwmdp_u0__A1_REG)
       #define DELAY1A_COUNTERCAP_LSB_PTR  ((reg8 *)   DELAY1A_PWMUDB_sP8_pwmdp_u0__A1_REG)
       #define DELAY1A_COUNTER_LSB         (*(reg8 *)  DELAY1A_PWMUDB_sP8_pwmdp_u0__A0_REG)
       #define DELAY1A_COUNTER_LSB_PTR     ((reg8 *)   DELAY1A_PWMUDB_sP8_pwmdp_u0__A0_REG)
       #define DELAY1A_CAPTURE_LSB         (*(reg8 *)  DELAY1A_PWMUDB_sP8_pwmdp_u0__F1_REG)
       #define DELAY1A_CAPTURE_LSB_PTR     ((reg8 *)   DELAY1A_PWMUDB_sP8_pwmdp_u0__F1_REG)

   #else
        #if(CY_PSOC3) /* 8-bit address space */
            #if(DELAY1A_PWMModeIsCenterAligned)
               #define DELAY1A_PERIOD_LSB      (*(reg16 *) DELAY1A_PWMUDB_sP8_pwmdp_u0__D1_REG)
               #define DELAY1A_PERIOD_LSB_PTR  ((reg16 *)  DELAY1A_PWMUDB_sP8_pwmdp_u0__D1_REG)
            #else
               #define DELAY1A_PERIOD_LSB      (*(reg16 *) DELAY1A_PWMUDB_sP8_pwmdp_u0__F0_REG)
               #define DELAY1A_PERIOD_LSB_PTR  ((reg16 *)  DELAY1A_PWMUDB_sP8_pwmdp_u0__F0_REG)
            #endif /* (DELAY1A_PWMModeIsCenterAligned) */

            #define DELAY1A_COMPARE1_LSB       (*(reg16 *) DELAY1A_PWMUDB_sP8_pwmdp_u0__D0_REG)
            #define DELAY1A_COMPARE1_LSB_PTR   ((reg16 *)  DELAY1A_PWMUDB_sP8_pwmdp_u0__D0_REG)
            #define DELAY1A_COMPARE2_LSB       (*(reg16 *) DELAY1A_PWMUDB_sP8_pwmdp_u0__D1_REG)
            #define DELAY1A_COMPARE2_LSB_PTR   ((reg16 *)  DELAY1A_PWMUDB_sP8_pwmdp_u0__D1_REG)
            #define DELAY1A_COUNTERCAP_LSB     (*(reg16 *) DELAY1A_PWMUDB_sP8_pwmdp_u0__A1_REG)
            #define DELAY1A_COUNTERCAP_LSB_PTR ((reg16 *)  DELAY1A_PWMUDB_sP8_pwmdp_u0__A1_REG)
            #define DELAY1A_COUNTER_LSB        (*(reg16 *) DELAY1A_PWMUDB_sP8_pwmdp_u0__A0_REG)
            #define DELAY1A_COUNTER_LSB_PTR    ((reg16 *)  DELAY1A_PWMUDB_sP8_pwmdp_u0__A0_REG)
            #define DELAY1A_CAPTURE_LSB        (*(reg16 *) DELAY1A_PWMUDB_sP8_pwmdp_u0__F1_REG)
            #define DELAY1A_CAPTURE_LSB_PTR    ((reg16 *)  DELAY1A_PWMUDB_sP8_pwmdp_u0__F1_REG)
        #else
            #if(DELAY1A_PWMModeIsCenterAligned)
               #define DELAY1A_PERIOD_LSB      (*(reg16 *) DELAY1A_PWMUDB_sP8_pwmdp_u0__16BIT_D1_REG)
               #define DELAY1A_PERIOD_LSB_PTR  ((reg16 *)  DELAY1A_PWMUDB_sP8_pwmdp_u0__16BIT_D1_REG)
            #else
               #define DELAY1A_PERIOD_LSB      (*(reg16 *) DELAY1A_PWMUDB_sP8_pwmdp_u0__16BIT_F0_REG)
               #define DELAY1A_PERIOD_LSB_PTR  ((reg16 *)  DELAY1A_PWMUDB_sP8_pwmdp_u0__16BIT_F0_REG)
            #endif /* (DELAY1A_PWMModeIsCenterAligned) */

            #define DELAY1A_COMPARE1_LSB       (*(reg16 *) DELAY1A_PWMUDB_sP8_pwmdp_u0__16BIT_D0_REG)
            #define DELAY1A_COMPARE1_LSB_PTR   ((reg16 *)  DELAY1A_PWMUDB_sP8_pwmdp_u0__16BIT_D0_REG)
            #define DELAY1A_COMPARE2_LSB       (*(reg16 *) DELAY1A_PWMUDB_sP8_pwmdp_u0__16BIT_D1_REG)
            #define DELAY1A_COMPARE2_LSB_PTR   ((reg16 *)  DELAY1A_PWMUDB_sP8_pwmdp_u0__16BIT_D1_REG)
            #define DELAY1A_COUNTERCAP_LSB     (*(reg16 *) DELAY1A_PWMUDB_sP8_pwmdp_u0__16BIT_A1_REG)
            #define DELAY1A_COUNTERCAP_LSB_PTR ((reg16 *)  DELAY1A_PWMUDB_sP8_pwmdp_u0__16BIT_A1_REG)
            #define DELAY1A_COUNTER_LSB        (*(reg16 *) DELAY1A_PWMUDB_sP8_pwmdp_u0__16BIT_A0_REG)
            #define DELAY1A_COUNTER_LSB_PTR    ((reg16 *)  DELAY1A_PWMUDB_sP8_pwmdp_u0__16BIT_A0_REG)
            #define DELAY1A_CAPTURE_LSB        (*(reg16 *) DELAY1A_PWMUDB_sP8_pwmdp_u0__16BIT_F1_REG)
            #define DELAY1A_CAPTURE_LSB_PTR    ((reg16 *)  DELAY1A_PWMUDB_sP8_pwmdp_u0__16BIT_F1_REG)
        #endif /* (CY_PSOC3) */

       #define DELAY1A_AUX_CONTROLDP1          (*(reg8 *)  DELAY1A_PWMUDB_sP8_pwmdp_u1__DP_AUX_CTL_REG)
       #define DELAY1A_AUX_CONTROLDP1_PTR      ((reg8 *)   DELAY1A_PWMUDB_sP8_pwmdp_u1__DP_AUX_CTL_REG)

   #endif /* (DELAY1A_Resolution == 8) */

   #define DELAY1A_COUNTERCAP_LSB_PTR_8BIT ( (reg8 *)  DELAY1A_PWMUDB_sP8_pwmdp_u0__A1_REG)
   #define DELAY1A_AUX_CONTROLDP0          (*(reg8 *)  DELAY1A_PWMUDB_sP8_pwmdp_u0__DP_AUX_CTL_REG)
   #define DELAY1A_AUX_CONTROLDP0_PTR      ((reg8 *)   DELAY1A_PWMUDB_sP8_pwmdp_u0__DP_AUX_CTL_REG)

#endif /* (DELAY1A_UsingFixedFunction) */

#if(DELAY1A_KillModeMinTime )
    #define DELAY1A_KILLMODEMINTIME        (*(reg8 *)  DELAY1A_PWMUDB_sKM_killmodecounterdp_u0__D0_REG)
    #define DELAY1A_KILLMODEMINTIME_PTR    ((reg8 *)   DELAY1A_PWMUDB_sKM_killmodecounterdp_u0__D0_REG)
    /* Fixed Function Block has no Kill Mode parameters because it is Asynchronous only */
#endif /* (DELAY1A_KillModeMinTime ) */

#if(DELAY1A_DeadBandMode == DELAY1A__B_PWM__DBM_256_CLOCKS)
    #define DELAY1A_DEADBAND_COUNT         (*(reg8 *)  DELAY1A_PWMUDB_sDB255_deadbandcounterdp_u0__D0_REG)
    #define DELAY1A_DEADBAND_COUNT_PTR     ((reg8 *)   DELAY1A_PWMUDB_sDB255_deadbandcounterdp_u0__D0_REG)
    #define DELAY1A_DEADBAND_LSB_PTR       ((reg8 *)   DELAY1A_PWMUDB_sDB255_deadbandcounterdp_u0__A0_REG)
    #define DELAY1A_DEADBAND_LSB           (*(reg8 *)  DELAY1A_PWMUDB_sDB255_deadbandcounterdp_u0__A0_REG)
#elif(DELAY1A_DeadBandMode == DELAY1A__B_PWM__DBM_2_4_CLOCKS)
    
    /* In Fixed Function Block these bits are in the control blocks control register */
    #if (DELAY1A_UsingFixedFunction)
        #define DELAY1A_DEADBAND_COUNT         (*(reg8 *)  DELAY1A_PWMHW__CFG0)
        #define DELAY1A_DEADBAND_COUNT_PTR     ((reg8 *)   DELAY1A_PWMHW__CFG0)
        #define DELAY1A_DEADBAND_COUNT_MASK    (uint8)((uint8)0x03u << DELAY1A_DEADBAND_COUNT_SHIFT)

        /* As defined by the Register Map as DEADBAND_PERIOD[1:0] in CFG0 */
        #define DELAY1A_DEADBAND_COUNT_SHIFT   (0x06u)
    #else
        /* Lower two bits of the added control register define the count 1-3 */
        #define DELAY1A_DEADBAND_COUNT         (*(reg8 *)  DELAY1A_PWMUDB_genblk7_dbctrlreg__CONTROL_REG)
        #define DELAY1A_DEADBAND_COUNT_PTR     ((reg8 *)   DELAY1A_PWMUDB_genblk7_dbctrlreg__CONTROL_REG)
        #define DELAY1A_DEADBAND_COUNT_MASK    (uint8)((uint8)0x03u << DELAY1A_DEADBAND_COUNT_SHIFT)

        /* As defined by the verilog implementation of the Control Register */
        #define DELAY1A_DEADBAND_COUNT_SHIFT   (0x00u)
    #endif /* (DELAY1A_UsingFixedFunction) */
#endif /* (DELAY1A_DeadBandMode == DELAY1A__B_PWM__DBM_256_CLOCKS) */



#if (DELAY1A_UsingFixedFunction)
    #define DELAY1A_STATUS                 (*(reg8 *) DELAY1A_PWMHW__SR0)
    #define DELAY1A_STATUS_PTR             ((reg8 *) DELAY1A_PWMHW__SR0)
    #define DELAY1A_STATUS_MASK            (*(reg8 *) DELAY1A_PWMHW__SR0)
    #define DELAY1A_STATUS_MASK_PTR        ((reg8 *) DELAY1A_PWMHW__SR0)
    #define DELAY1A_CONTROL                (*(reg8 *) DELAY1A_PWMHW__CFG0)
    #define DELAY1A_CONTROL_PTR            ((reg8 *) DELAY1A_PWMHW__CFG0)
    #define DELAY1A_CONTROL2               (*(reg8 *) DELAY1A_PWMHW__CFG1)
    #define DELAY1A_CONTROL3               (*(reg8 *) DELAY1A_PWMHW__CFG2)
    #define DELAY1A_GLOBAL_ENABLE          (*(reg8 *) DELAY1A_PWMHW__PM_ACT_CFG)
    #define DELAY1A_GLOBAL_ENABLE_PTR      ( (reg8 *) DELAY1A_PWMHW__PM_ACT_CFG)
    #define DELAY1A_GLOBAL_STBY_ENABLE     (*(reg8 *) DELAY1A_PWMHW__PM_STBY_CFG)
    #define DELAY1A_GLOBAL_STBY_ENABLE_PTR ( (reg8 *) DELAY1A_PWMHW__PM_STBY_CFG)


    /***********************************
    *          Constants
    ***********************************/

    /* Fixed Function Block Chosen */
    #define DELAY1A_BLOCK_EN_MASK          (DELAY1A_PWMHW__PM_ACT_MSK)
    #define DELAY1A_BLOCK_STBY_EN_MASK     (DELAY1A_PWMHW__PM_STBY_MSK)
    
    /* Control Register definitions */
    #define DELAY1A_CTRL_ENABLE_SHIFT      (0x00u)

    /* As defined by Register map as MODE_CFG bits in CFG2*/
    #define DELAY1A_CTRL_CMPMODE1_SHIFT    (0x04u)

    /* As defined by Register map */
    #define DELAY1A_CTRL_DEAD_TIME_SHIFT   (0x06u)  

    /* Fixed Function Block Only CFG register bit definitions */
    /*  Set to compare mode */
    #define DELAY1A_CFG0_MODE              (0x02u)   

    /* Enable the block to run */
    #define DELAY1A_CFG0_ENABLE            (0x01u)   
    
    /* As defined by Register map as DB bit in CFG0 */
    #define DELAY1A_CFG0_DB                (0x20u)   

    /* Control Register Bit Masks */
    #define DELAY1A_CTRL_ENABLE            (uint8)((uint8)0x01u << DELAY1A_CTRL_ENABLE_SHIFT)
    #define DELAY1A_CTRL_RESET             (uint8)((uint8)0x01u << DELAY1A_CTRL_RESET_SHIFT)
    #define DELAY1A_CTRL_CMPMODE2_MASK     (uint8)((uint8)0x07u << DELAY1A_CTRL_CMPMODE2_SHIFT)
    #define DELAY1A_CTRL_CMPMODE1_MASK     (uint8)((uint8)0x07u << DELAY1A_CTRL_CMPMODE1_SHIFT)

    /* Control2 Register Bit Masks */
    /* As defined in Register Map, Part of the TMRX_CFG1 register */
    #define DELAY1A_CTRL2_IRQ_SEL_SHIFT    (0x00u)
    #define DELAY1A_CTRL2_IRQ_SEL          (uint8)((uint8)0x01u << DELAY1A_CTRL2_IRQ_SEL_SHIFT)

    /* Status Register Bit Locations */
    /* As defined by Register map as TC in SR0 */
    #define DELAY1A_STATUS_TC_SHIFT        (0x07u)   
    
    /* As defined by the Register map as CAP_CMP in SR0 */
    #define DELAY1A_STATUS_CMP1_SHIFT      (0x06u)   

    /* Status Register Interrupt Enable Bit Locations */
    #define DELAY1A_STATUS_KILL_INT_EN_MASK_SHIFT          (0x00u)
    #define DELAY1A_STATUS_TC_INT_EN_MASK_SHIFT            (DELAY1A_STATUS_TC_SHIFT - 4u)
    #define DELAY1A_STATUS_CMP2_INT_EN_MASK_SHIFT          (0x00u)
    #define DELAY1A_STATUS_CMP1_INT_EN_MASK_SHIFT          (DELAY1A_STATUS_CMP1_SHIFT - 4u)

    /* Status Register Bit Masks */
    #define DELAY1A_STATUS_TC              (uint8)((uint8)0x01u << DELAY1A_STATUS_TC_SHIFT)
    #define DELAY1A_STATUS_CMP1            (uint8)((uint8)0x01u << DELAY1A_STATUS_CMP1_SHIFT)

    /* Status Register Interrupt Bit Masks */
    #define DELAY1A_STATUS_TC_INT_EN_MASK              (uint8)((uint8)DELAY1A_STATUS_TC >> 4u)
    #define DELAY1A_STATUS_CMP1_INT_EN_MASK            (uint8)((uint8)DELAY1A_STATUS_CMP1 >> 4u)

    /*RT1 Synch Constants */
    #define DELAY1A_RT1_SHIFT             (0x04u)

    /* Sync TC and CMP bit masks */
    #define DELAY1A_RT1_MASK              (uint8)((uint8)0x03u << DELAY1A_RT1_SHIFT)
    #define DELAY1A_SYNC                  (uint8)((uint8)0x03u << DELAY1A_RT1_SHIFT)
    #define DELAY1A_SYNCDSI_SHIFT         (0x00u)

    /* Sync all DSI inputs */
    #define DELAY1A_SYNCDSI_MASK          (uint8)((uint8)0x0Fu << DELAY1A_SYNCDSI_SHIFT)

    /* Sync all DSI inputs */
    #define DELAY1A_SYNCDSI_EN            (uint8)((uint8)0x0Fu << DELAY1A_SYNCDSI_SHIFT)


#else
    #define DELAY1A_STATUS                (*(reg8 *)   DELAY1A_PWMUDB_genblk8_stsreg__STATUS_REG )
    #define DELAY1A_STATUS_PTR            ((reg8 *)    DELAY1A_PWMUDB_genblk8_stsreg__STATUS_REG )
    #define DELAY1A_STATUS_MASK           (*(reg8 *)   DELAY1A_PWMUDB_genblk8_stsreg__MASK_REG)
    #define DELAY1A_STATUS_MASK_PTR       ((reg8 *)    DELAY1A_PWMUDB_genblk8_stsreg__MASK_REG)
    #define DELAY1A_STATUS_AUX_CTRL       (*(reg8 *)   DELAY1A_PWMUDB_genblk8_stsreg__STATUS_AUX_CTL_REG)
    #define DELAY1A_CONTROL               (*(reg8 *)   DELAY1A_PWMUDB_genblk1_ctrlreg__CONTROL_REG)
    #define DELAY1A_CONTROL_PTR           ((reg8 *)    DELAY1A_PWMUDB_genblk1_ctrlreg__CONTROL_REG)


    /***********************************
    *          Constants
    ***********************************/

    /* Control Register bit definitions */
    #define DELAY1A_CTRL_ENABLE_SHIFT      (0x07u)
    #define DELAY1A_CTRL_RESET_SHIFT       (0x06u)
    #define DELAY1A_CTRL_CMPMODE2_SHIFT    (0x03u)
    #define DELAY1A_CTRL_CMPMODE1_SHIFT    (0x00u)
    #define DELAY1A_CTRL_DEAD_TIME_SHIFT   (0x00u)   /* No Shift Needed for UDB block */
    
    /* Control Register Bit Masks */
    #define DELAY1A_CTRL_ENABLE            (uint8)((uint8)0x01u << DELAY1A_CTRL_ENABLE_SHIFT)
    #define DELAY1A_CTRL_RESET             (uint8)((uint8)0x01u << DELAY1A_CTRL_RESET_SHIFT)
    #define DELAY1A_CTRL_CMPMODE2_MASK     (uint8)((uint8)0x07u << DELAY1A_CTRL_CMPMODE2_SHIFT)
    #define DELAY1A_CTRL_CMPMODE1_MASK     (uint8)((uint8)0x07u << DELAY1A_CTRL_CMPMODE1_SHIFT)

    /* Status Register Bit Locations */
    #define DELAY1A_STATUS_KILL_SHIFT          (0x05u)
    #define DELAY1A_STATUS_FIFONEMPTY_SHIFT    (0x04u)
    #define DELAY1A_STATUS_FIFOFULL_SHIFT      (0x03u)
    #define DELAY1A_STATUS_TC_SHIFT            (0x02u)
    #define DELAY1A_STATUS_CMP2_SHIFT          (0x01u)
    #define DELAY1A_STATUS_CMP1_SHIFT          (0x00u)

    /* Status Register Interrupt Enable Bit Locations - UDB Status Interrupt Mask match Status Bit Locations*/
    #define DELAY1A_STATUS_KILL_INT_EN_MASK_SHIFT          (DELAY1A_STATUS_KILL_SHIFT)
    #define DELAY1A_STATUS_FIFONEMPTY_INT_EN_MASK_SHIFT    (DELAY1A_STATUS_FIFONEMPTY_SHIFT)
    #define DELAY1A_STATUS_FIFOFULL_INT_EN_MASK_SHIFT      (DELAY1A_STATUS_FIFOFULL_SHIFT)
    #define DELAY1A_STATUS_TC_INT_EN_MASK_SHIFT            (DELAY1A_STATUS_TC_SHIFT)
    #define DELAY1A_STATUS_CMP2_INT_EN_MASK_SHIFT          (DELAY1A_STATUS_CMP2_SHIFT)
    #define DELAY1A_STATUS_CMP1_INT_EN_MASK_SHIFT          (DELAY1A_STATUS_CMP1_SHIFT)

    /* Status Register Bit Masks */
    #define DELAY1A_STATUS_KILL            (uint8)((uint8)0x00u << DELAY1A_STATUS_KILL_SHIFT )
    #define DELAY1A_STATUS_FIFOFULL        (uint8)((uint8)0x01u << DELAY1A_STATUS_FIFOFULL_SHIFT)
    #define DELAY1A_STATUS_FIFONEMPTY      (uint8)((uint8)0x01u << DELAY1A_STATUS_FIFONEMPTY_SHIFT)
    #define DELAY1A_STATUS_TC              (uint8)((uint8)0x01u << DELAY1A_STATUS_TC_SHIFT)
    #define DELAY1A_STATUS_CMP2            (uint8)((uint8)0x01u << DELAY1A_STATUS_CMP2_SHIFT)
    #define DELAY1A_STATUS_CMP1            (uint8)((uint8)0x01u << DELAY1A_STATUS_CMP1_SHIFT)

    /* Status Register Interrupt Bit Masks  - UDB Status Interrupt Mask match Status Bit Locations */
    #define DELAY1A_STATUS_KILL_INT_EN_MASK            (DELAY1A_STATUS_KILL)
    #define DELAY1A_STATUS_FIFOFULL_INT_EN_MASK        (DELAY1A_STATUS_FIFOFULL)
    #define DELAY1A_STATUS_FIFONEMPTY_INT_EN_MASK      (DELAY1A_STATUS_FIFONEMPTY)
    #define DELAY1A_STATUS_TC_INT_EN_MASK              (DELAY1A_STATUS_TC)
    #define DELAY1A_STATUS_CMP2_INT_EN_MASK            (DELAY1A_STATUS_CMP2)
    #define DELAY1A_STATUS_CMP1_INT_EN_MASK            (DELAY1A_STATUS_CMP1)

    /* Datapath Auxillary Control Register bit definitions */
    #define DELAY1A_AUX_CTRL_FIFO0_CLR         (0x01u)
    #define DELAY1A_AUX_CTRL_FIFO1_CLR         (0x02u)
    #define DELAY1A_AUX_CTRL_FIFO0_LVL         (0x04u)
    #define DELAY1A_AUX_CTRL_FIFO1_LVL         (0x08u)
    #define DELAY1A_STATUS_ACTL_INT_EN_MASK    (0x10u) /* As defined for the ACTL Register */
#endif /* DELAY1A_UsingFixedFunction */

#endif  /* CY_PWM_DELAY1A_H */


/* [] END OF FILE */
