/*******************************************************************************
* File Name: DELAY1A_PM.c
* Version 3.30
*
* Description:
*  This file provides the power management source code to API for the
*  PWM.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "DELAY1A.h"

static DELAY1A_backupStruct DELAY1A_backup;


/*******************************************************************************
* Function Name: DELAY1A_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the current user configuration of the component.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  DELAY1A_backup:  Variables of this global structure are modified to
*  store the values of non retention configuration registers when Sleep() API is
*  called.
*
*******************************************************************************/
void DELAY1A_SaveConfig(void) 
{

    #if(!DELAY1A_UsingFixedFunction)
        #if(!DELAY1A_PWMModeIsCenterAligned)
            DELAY1A_backup.PWMPeriod = DELAY1A_ReadPeriod();
        #endif /* (!DELAY1A_PWMModeIsCenterAligned) */
        DELAY1A_backup.PWMUdb = DELAY1A_ReadCounter();
        #if (DELAY1A_UseStatus)
            DELAY1A_backup.InterruptMaskValue = DELAY1A_STATUS_MASK;
        #endif /* (DELAY1A_UseStatus) */

        #if(DELAY1A_DeadBandMode == DELAY1A__B_PWM__DBM_256_CLOCKS || \
            DELAY1A_DeadBandMode == DELAY1A__B_PWM__DBM_2_4_CLOCKS)
            DELAY1A_backup.PWMdeadBandValue = DELAY1A_ReadDeadTime();
        #endif /*  deadband count is either 2-4 clocks or 256 clocks */

        #if(DELAY1A_KillModeMinTime)
             DELAY1A_backup.PWMKillCounterPeriod = DELAY1A_ReadKillTime();
        #endif /* (DELAY1A_KillModeMinTime) */

        #if(DELAY1A_UseControl)
            DELAY1A_backup.PWMControlRegister = DELAY1A_ReadControlRegister();
        #endif /* (DELAY1A_UseControl) */
    #endif  /* (!DELAY1A_UsingFixedFunction) */
}


/*******************************************************************************
* Function Name: DELAY1A_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration of the component.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  DELAY1A_backup:  Variables of this global structure are used to
*  restore the values of non retention registers on wakeup from sleep mode.
*
*******************************************************************************/
void DELAY1A_RestoreConfig(void) 
{
        #if(!DELAY1A_UsingFixedFunction)
            #if(!DELAY1A_PWMModeIsCenterAligned)
                DELAY1A_WritePeriod(DELAY1A_backup.PWMPeriod);
            #endif /* (!DELAY1A_PWMModeIsCenterAligned) */

            DELAY1A_WriteCounter(DELAY1A_backup.PWMUdb);

            #if (DELAY1A_UseStatus)
                DELAY1A_STATUS_MASK = DELAY1A_backup.InterruptMaskValue;
            #endif /* (DELAY1A_UseStatus) */

            #if(DELAY1A_DeadBandMode == DELAY1A__B_PWM__DBM_256_CLOCKS || \
                DELAY1A_DeadBandMode == DELAY1A__B_PWM__DBM_2_4_CLOCKS)
                DELAY1A_WriteDeadTime(DELAY1A_backup.PWMdeadBandValue);
            #endif /* deadband count is either 2-4 clocks or 256 clocks */

            #if(DELAY1A_KillModeMinTime)
                DELAY1A_WriteKillTime(DELAY1A_backup.PWMKillCounterPeriod);
            #endif /* (DELAY1A_KillModeMinTime) */

            #if(DELAY1A_UseControl)
                DELAY1A_WriteControlRegister(DELAY1A_backup.PWMControlRegister);
            #endif /* (DELAY1A_UseControl) */
        #endif  /* (!DELAY1A_UsingFixedFunction) */
    }


/*******************************************************************************
* Function Name: DELAY1A_Sleep
********************************************************************************
*
* Summary:
*  Disables block's operation and saves the user configuration. Should be called
*  just prior to entering sleep.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  DELAY1A_backup.PWMEnableState:  Is modified depending on the enable
*  state of the block before entering sleep mode.
*
*******************************************************************************/
void DELAY1A_Sleep(void) 
{
    #if(DELAY1A_UseControl)
        if(DELAY1A_CTRL_ENABLE == (DELAY1A_CONTROL & DELAY1A_CTRL_ENABLE))
        {
            /*Component is enabled */
            DELAY1A_backup.PWMEnableState = 1u;
        }
        else
        {
            /* Component is disabled */
            DELAY1A_backup.PWMEnableState = 0u;
        }
    #endif /* (DELAY1A_UseControl) */

    /* Stop component */
    DELAY1A_Stop();

    /* Save registers configuration */
    DELAY1A_SaveConfig();
}


/*******************************************************************************
* Function Name: DELAY1A_Wakeup
********************************************************************************
*
* Summary:
*  Restores and enables the user configuration. Should be called just after
*  awaking from sleep.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  DELAY1A_backup.pwmEnable:  Is used to restore the enable state of
*  block on wakeup from sleep mode.
*
*******************************************************************************/
void DELAY1A_Wakeup(void) 
{
     /* Restore registers values */
    DELAY1A_RestoreConfig();

    if(DELAY1A_backup.PWMEnableState != 0u)
    {
        /* Enable component's operation */
        DELAY1A_Enable();
    } /* Do nothing if component's block was disabled before */

}


/* [] END OF FILE */
