/*******************************************************************************
* File Name: DELAY1B_PM.c
* Version 3.30
*
* Description:
*  This file provides the power management source code to API for the
*  PWM.
*
* Note:
*
********************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/

#include "DELAY1B.h"

static DELAY1B_backupStruct DELAY1B_backup;


/*******************************************************************************
* Function Name: DELAY1B_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the current user configuration of the component.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  DELAY1B_backup:  Variables of this global structure are modified to
*  store the values of non retention configuration registers when Sleep() API is
*  called.
*
*******************************************************************************/
void DELAY1B_SaveConfig(void) 
{

    #if(!DELAY1B_UsingFixedFunction)
        #if(!DELAY1B_PWMModeIsCenterAligned)
            DELAY1B_backup.PWMPeriod = DELAY1B_ReadPeriod();
        #endif /* (!DELAY1B_PWMModeIsCenterAligned) */
        DELAY1B_backup.PWMUdb = DELAY1B_ReadCounter();
        #if (DELAY1B_UseStatus)
            DELAY1B_backup.InterruptMaskValue = DELAY1B_STATUS_MASK;
        #endif /* (DELAY1B_UseStatus) */

        #if(DELAY1B_DeadBandMode == DELAY1B__B_PWM__DBM_256_CLOCKS || \
            DELAY1B_DeadBandMode == DELAY1B__B_PWM__DBM_2_4_CLOCKS)
            DELAY1B_backup.PWMdeadBandValue = DELAY1B_ReadDeadTime();
        #endif /*  deadband count is either 2-4 clocks or 256 clocks */

        #if(DELAY1B_KillModeMinTime)
             DELAY1B_backup.PWMKillCounterPeriod = DELAY1B_ReadKillTime();
        #endif /* (DELAY1B_KillModeMinTime) */

        #if(DELAY1B_UseControl)
            DELAY1B_backup.PWMControlRegister = DELAY1B_ReadControlRegister();
        #endif /* (DELAY1B_UseControl) */
    #endif  /* (!DELAY1B_UsingFixedFunction) */
}


/*******************************************************************************
* Function Name: DELAY1B_RestoreConfig
********************************************************************************
*
* Summary:
*  Restores the current user configuration of the component.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  DELAY1B_backup:  Variables of this global structure are used to
*  restore the values of non retention registers on wakeup from sleep mode.
*
*******************************************************************************/
void DELAY1B_RestoreConfig(void) 
{
        #if(!DELAY1B_UsingFixedFunction)
            #if(!DELAY1B_PWMModeIsCenterAligned)
                DELAY1B_WritePeriod(DELAY1B_backup.PWMPeriod);
            #endif /* (!DELAY1B_PWMModeIsCenterAligned) */

            DELAY1B_WriteCounter(DELAY1B_backup.PWMUdb);

            #if (DELAY1B_UseStatus)
                DELAY1B_STATUS_MASK = DELAY1B_backup.InterruptMaskValue;
            #endif /* (DELAY1B_UseStatus) */

            #if(DELAY1B_DeadBandMode == DELAY1B__B_PWM__DBM_256_CLOCKS || \
                DELAY1B_DeadBandMode == DELAY1B__B_PWM__DBM_2_4_CLOCKS)
                DELAY1B_WriteDeadTime(DELAY1B_backup.PWMdeadBandValue);
            #endif /* deadband count is either 2-4 clocks or 256 clocks */

            #if(DELAY1B_KillModeMinTime)
                DELAY1B_WriteKillTime(DELAY1B_backup.PWMKillCounterPeriod);
            #endif /* (DELAY1B_KillModeMinTime) */

            #if(DELAY1B_UseControl)
                DELAY1B_WriteControlRegister(DELAY1B_backup.PWMControlRegister);
            #endif /* (DELAY1B_UseControl) */
        #endif  /* (!DELAY1B_UsingFixedFunction) */
    }


/*******************************************************************************
* Function Name: DELAY1B_Sleep
********************************************************************************
*
* Summary:
*  Disables block's operation and saves the user configuration. Should be called
*  just prior to entering sleep.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  DELAY1B_backup.PWMEnableState:  Is modified depending on the enable
*  state of the block before entering sleep mode.
*
*******************************************************************************/
void DELAY1B_Sleep(void) 
{
    #if(DELAY1B_UseControl)
        if(DELAY1B_CTRL_ENABLE == (DELAY1B_CONTROL & DELAY1B_CTRL_ENABLE))
        {
            /*Component is enabled */
            DELAY1B_backup.PWMEnableState = 1u;
        }
        else
        {
            /* Component is disabled */
            DELAY1B_backup.PWMEnableState = 0u;
        }
    #endif /* (DELAY1B_UseControl) */

    /* Stop component */
    DELAY1B_Stop();

    /* Save registers configuration */
    DELAY1B_SaveConfig();
}


/*******************************************************************************
* Function Name: DELAY1B_Wakeup
********************************************************************************
*
* Summary:
*  Restores and enables the user configuration. Should be called just after
*  awaking from sleep.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  DELAY1B_backup.pwmEnable:  Is used to restore the enable state of
*  block on wakeup from sleep mode.
*
*******************************************************************************/
void DELAY1B_Wakeup(void) 
{
     /* Restore registers values */
    DELAY1B_RestoreConfig();

    if(DELAY1B_backup.PWMEnableState != 0u)
    {
        /* Enable component's operation */
        DELAY1B_Enable();
    } /* Do nothing if component's block was disabled before */

}


/* [] END OF FILE */
