/*******************************************************************************
* File Name: DELAY2B.c
* Version 3.30
*
* Description:
*  The PWM User Module consist of an 8 or 16-bit counter with two 8 or 16-bit
*  comparitors. Each instance of this user module is capable of generating
*  two PWM outputs with the same period. The pulse width is selectable between
*  1 and 255/65535. The period is selectable between 2 and 255/65536 clocks.
*  The compare value output may be configured to be active when the present
*  counter is less than or less than/equal to the compare value.
*  A terminal count output is also provided. It generates a pulse one clock
*  width wide when the counter is equal to zero.
*
* Note:
*
*******************************************************************************
* Copyright 2008-2014, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
********************************************************************************/

#include "DELAY2B.h"

/* Error message for removed <resource> through optimization */
#ifdef DELAY2B_PWMUDB_genblk1_ctrlreg__REMOVED
    #error PWM_v3_30 detected with a constant 0 for the enable or \
         constant 1 for reset. This will prevent the component from operating.
#endif /* DELAY2B_PWMUDB_genblk1_ctrlreg__REMOVED */

uint8 DELAY2B_initVar = 0u;


/*******************************************************************************
* Function Name: DELAY2B_Start
********************************************************************************
*
* Summary:
*  The start function initializes the pwm with the default values, the
*  enables the counter to begin counting.  It does not enable interrupts,
*  the EnableInt command should be called if interrupt generation is required.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Global variables:
*  DELAY2B_initVar: Is modified when this function is called for the
*   first time. Is used to ensure that initialization happens only once.
*
*******************************************************************************/
void DELAY2B_Start(void) 
{
    /* If not Initialized then initialize all required hardware and software */
    if(DELAY2B_initVar == 0u)
    {
        DELAY2B_Init();
        DELAY2B_initVar = 1u;
    }
    DELAY2B_Enable();

}


/*******************************************************************************
* Function Name: DELAY2B_Init
********************************************************************************
*
* Summary:
*  Initialize component's parameters to the parameters set by user in the
*  customizer of the component placed onto schematic. Usually called in
*  DELAY2B_Start().
*
* Parameters:
*  None
*
* Return:
*  None
*
*******************************************************************************/
void DELAY2B_Init(void) 
{
    #if (DELAY2B_UsingFixedFunction || DELAY2B_UseControl)
        uint8 ctrl;
    #endif /* (DELAY2B_UsingFixedFunction || DELAY2B_UseControl) */

    #if(!DELAY2B_UsingFixedFunction)
        #if(DELAY2B_UseStatus)
            /* Interrupt State Backup for Critical Region*/
            uint8 DELAY2B_interruptState;
        #endif /* (DELAY2B_UseStatus) */
    #endif /* (!DELAY2B_UsingFixedFunction) */

    #if (DELAY2B_UsingFixedFunction)
        /* You are allowed to write the compare value (FF only) */
        DELAY2B_CONTROL |= DELAY2B_CFG0_MODE;
        #if (DELAY2B_DeadBand2_4)
            DELAY2B_CONTROL |= DELAY2B_CFG0_DB;
        #endif /* (DELAY2B_DeadBand2_4) */

        ctrl = DELAY2B_CONTROL3 & ((uint8 )(~DELAY2B_CTRL_CMPMODE1_MASK));
        DELAY2B_CONTROL3 = ctrl | DELAY2B_DEFAULT_COMPARE1_MODE;

         /* Clear and Set SYNCTC and SYNCCMP bits of RT1 register */
        DELAY2B_RT1 &= ((uint8)(~DELAY2B_RT1_MASK));
        DELAY2B_RT1 |= DELAY2B_SYNC;

        /*Enable DSI Sync all all inputs of the PWM*/
        DELAY2B_RT1 &= ((uint8)(~DELAY2B_SYNCDSI_MASK));
        DELAY2B_RT1 |= DELAY2B_SYNCDSI_EN;

    #elif (DELAY2B_UseControl)
        /* Set the default compare mode defined in the parameter */
        ctrl = DELAY2B_CONTROL & ((uint8)(~DELAY2B_CTRL_CMPMODE2_MASK)) &
                ((uint8)(~DELAY2B_CTRL_CMPMODE1_MASK));
        DELAY2B_CONTROL = ctrl | DELAY2B_DEFAULT_COMPARE2_MODE |
                                   DELAY2B_DEFAULT_COMPARE1_MODE;
    #endif /* (DELAY2B_UsingFixedFunction) */

    #if (!DELAY2B_UsingFixedFunction)
        #if (DELAY2B_Resolution == 8)
            /* Set FIFO 0 to 1 byte register for period*/
            DELAY2B_AUX_CONTROLDP0 |= (DELAY2B_AUX_CTRL_FIFO0_CLR);
        #else /* (DELAY2B_Resolution == 16)*/
            /* Set FIFO 0 to 1 byte register for period */
            DELAY2B_AUX_CONTROLDP0 |= (DELAY2B_AUX_CTRL_FIFO0_CLR);
            DELAY2B_AUX_CONTROLDP1 |= (DELAY2B_AUX_CTRL_FIFO0_CLR);
        #endif /* (DELAY2B_Resolution == 8) */

        DELAY2B_WriteCounter(DELAY2B_INIT_PERIOD_VALUE);
    #endif /* (!DELAY2B_UsingFixedFunction) */

    DELAY2B_WritePeriod(DELAY2B_INIT_PERIOD_VALUE);

        #if (DELAY2B_UseOneCompareMode)
            DELAY2B_WriteCompare(DELAY2B_INIT_COMPARE_VALUE1);
        #else
            DELAY2B_WriteCompare1(DELAY2B_INIT_COMPARE_VALUE1);
            DELAY2B_WriteCompare2(DELAY2B_INIT_COMPARE_VALUE2);
        #endif /* (DELAY2B_UseOneCompareMode) */

        #if (DELAY2B_KillModeMinTime)
            DELAY2B_WriteKillTime(DELAY2B_MinimumKillTime);
        #endif /* (DELAY2B_KillModeMinTime) */

        #if (DELAY2B_DeadBandUsed)
            DELAY2B_WriteDeadTime(DELAY2B_INIT_DEAD_TIME);
        #endif /* (DELAY2B_DeadBandUsed) */

    #if (DELAY2B_UseStatus || DELAY2B_UsingFixedFunction)
        DELAY2B_SetInterruptMode(DELAY2B_INIT_INTERRUPTS_MODE);
    #endif /* (DELAY2B_UseStatus || DELAY2B_UsingFixedFunction) */

    #if (DELAY2B_UsingFixedFunction)
        /* Globally Enable the Fixed Function Block chosen */
        DELAY2B_GLOBAL_ENABLE |= DELAY2B_BLOCK_EN_MASK;
        /* Set the Interrupt source to come from the status register */
        DELAY2B_CONTROL2 |= DELAY2B_CTRL2_IRQ_SEL;
    #else
        #if(DELAY2B_UseStatus)

            /* CyEnterCriticalRegion and CyExitCriticalRegion are used to mark following region critical*/
            /* Enter Critical Region*/
            DELAY2B_interruptState = CyEnterCriticalSection();
            /* Use the interrupt output of the status register for IRQ output */
            DELAY2B_STATUS_AUX_CTRL |= DELAY2B_STATUS_ACTL_INT_EN_MASK;

             /* Exit Critical Region*/
            CyExitCriticalSection(DELAY2B_interruptState);

            /* Clear the FIFO to enable the DELAY2B_STATUS_FIFOFULL
                   bit to be set on FIFO full. */
            DELAY2B_ClearFIFO();
        #endif /* (DELAY2B_UseStatus) */
    #endif /* (DELAY2B_UsingFixedFunction) */
}


/*******************************************************************************
* Function Name: DELAY2B_Enable
********************************************************************************
*
* Summary:
*  Enables the PWM block operation
*
* Parameters:
*  None
*
* Return:
*  None
*
* Side Effects:
*  This works only if software enable mode is chosen
*
*******************************************************************************/
void DELAY2B_Enable(void) 
{
    /* Globally Enable the Fixed Function Block chosen */
    #if (DELAY2B_UsingFixedFunction)
        DELAY2B_GLOBAL_ENABLE |= DELAY2B_BLOCK_EN_MASK;
        DELAY2B_GLOBAL_STBY_ENABLE |= DELAY2B_BLOCK_STBY_EN_MASK;
    #endif /* (DELAY2B_UsingFixedFunction) */

    /* Enable the PWM from the control register  */
    #if (DELAY2B_UseControl || DELAY2B_UsingFixedFunction)
        DELAY2B_CONTROL |= DELAY2B_CTRL_ENABLE;
    #endif /* (DELAY2B_UseControl || DELAY2B_UsingFixedFunction) */
}


/*******************************************************************************
* Function Name: DELAY2B_Stop
********************************************************************************
*
* Summary:
*  The stop function halts the PWM, but does not change any modes or disable
*  interrupts.
*
* Parameters:
*  None
*
* Return:
*  None
*
* Side Effects:
*  If the Enable mode is set to Hardware only then this function
*  has no effect on the operation of the PWM
*
*******************************************************************************/
void DELAY2B_Stop(void) 
{
    #if (DELAY2B_UseControl || DELAY2B_UsingFixedFunction)
        DELAY2B_CONTROL &= ((uint8)(~DELAY2B_CTRL_ENABLE));
    #endif /* (DELAY2B_UseControl || DELAY2B_UsingFixedFunction) */

    /* Globally disable the Fixed Function Block chosen */
    #if (DELAY2B_UsingFixedFunction)
        DELAY2B_GLOBAL_ENABLE &= ((uint8)(~DELAY2B_BLOCK_EN_MASK));
        DELAY2B_GLOBAL_STBY_ENABLE &= ((uint8)(~DELAY2B_BLOCK_STBY_EN_MASK));
    #endif /* (DELAY2B_UsingFixedFunction) */
}

#if (DELAY2B_UseOneCompareMode)
    #if (DELAY2B_CompareMode1SW)


        /*******************************************************************************
        * Function Name: DELAY2B_SetCompareMode
        ********************************************************************************
        *
        * Summary:
        *  This function writes the Compare Mode for the pwm output when in Dither mode,
        *  Center Align Mode or One Output Mode.
        *
        * Parameters:
        *  comparemode:  The new compare mode for the PWM output. Use the compare types
        *                defined in the H file as input arguments.
        *
        * Return:
        *  None
        *
        *******************************************************************************/
        void DELAY2B_SetCompareMode(uint8 comparemode) 
        {
            #if(DELAY2B_UsingFixedFunction)

                #if(0 != DELAY2B_CTRL_CMPMODE1_SHIFT)
                    uint8 comparemodemasked = ((uint8)((uint8)comparemode << DELAY2B_CTRL_CMPMODE1_SHIFT));
                #else
                    uint8 comparemodemasked = comparemode;
                #endif /* (0 != DELAY2B_CTRL_CMPMODE1_SHIFT) */

                DELAY2B_CONTROL3 &= ((uint8)(~DELAY2B_CTRL_CMPMODE1_MASK)); /*Clear Existing Data */
                DELAY2B_CONTROL3 |= comparemodemasked;

            #elif (DELAY2B_UseControl)

                #if(0 != DELAY2B_CTRL_CMPMODE1_SHIFT)
                    uint8 comparemode1masked = ((uint8)((uint8)comparemode << DELAY2B_CTRL_CMPMODE1_SHIFT)) &
                                                DELAY2B_CTRL_CMPMODE1_MASK;
                #else
                    uint8 comparemode1masked = comparemode & DELAY2B_CTRL_CMPMODE1_MASK;
                #endif /* (0 != DELAY2B_CTRL_CMPMODE1_SHIFT) */

                #if(0 != DELAY2B_CTRL_CMPMODE2_SHIFT)
                    uint8 comparemode2masked = ((uint8)((uint8)comparemode << DELAY2B_CTRL_CMPMODE2_SHIFT)) &
                                               DELAY2B_CTRL_CMPMODE2_MASK;
                #else
                    uint8 comparemode2masked = comparemode & DELAY2B_CTRL_CMPMODE2_MASK;
                #endif /* (0 != DELAY2B_CTRL_CMPMODE2_SHIFT) */

                /*Clear existing mode */
                DELAY2B_CONTROL &= ((uint8)(~(DELAY2B_CTRL_CMPMODE1_MASK |
                                            DELAY2B_CTRL_CMPMODE2_MASK)));
                DELAY2B_CONTROL |= (comparemode1masked | comparemode2masked);

            #else
                uint8 temp = comparemode;
            #endif /* (DELAY2B_UsingFixedFunction) */
        }
    #endif /* DELAY2B_CompareMode1SW */

#else /* UseOneCompareMode */

    #if (DELAY2B_CompareMode1SW)


        /*******************************************************************************
        * Function Name: DELAY2B_SetCompareMode1
        ********************************************************************************
        *
        * Summary:
        *  This function writes the Compare Mode for the pwm or pwm1 output
        *
        * Parameters:
        *  comparemode:  The new compare mode for the PWM output. Use the compare types
        *                defined in the H file as input arguments.
        *
        * Return:
        *  None
        *
        *******************************************************************************/
        void DELAY2B_SetCompareMode1(uint8 comparemode) 
        {
            #if(0 != DELAY2B_CTRL_CMPMODE1_SHIFT)
                uint8 comparemodemasked = ((uint8)((uint8)comparemode << DELAY2B_CTRL_CMPMODE1_SHIFT)) &
                                           DELAY2B_CTRL_CMPMODE1_MASK;
            #else
                uint8 comparemodemasked = comparemode & DELAY2B_CTRL_CMPMODE1_MASK;
            #endif /* (0 != DELAY2B_CTRL_CMPMODE1_SHIFT) */

            #if (DELAY2B_UseControl)
                DELAY2B_CONTROL &= ((uint8)(~DELAY2B_CTRL_CMPMODE1_MASK)); /*Clear existing mode */
                DELAY2B_CONTROL |= comparemodemasked;
            #endif /* (DELAY2B_UseControl) */
        }
    #endif /* DELAY2B_CompareMode1SW */

#if (DELAY2B_CompareMode2SW)


    /*******************************************************************************
    * Function Name: DELAY2B_SetCompareMode2
    ********************************************************************************
    *
    * Summary:
    *  This function writes the Compare Mode for the pwm or pwm2 output
    *
    * Parameters:
    *  comparemode:  The new compare mode for the PWM output. Use the compare types
    *                defined in the H file as input arguments.
    *
    * Return:
    *  None
    *
    *******************************************************************************/
    void DELAY2B_SetCompareMode2(uint8 comparemode) 
    {

        #if(0 != DELAY2B_CTRL_CMPMODE2_SHIFT)
            uint8 comparemodemasked = ((uint8)((uint8)comparemode << DELAY2B_CTRL_CMPMODE2_SHIFT)) &
                                                 DELAY2B_CTRL_CMPMODE2_MASK;
        #else
            uint8 comparemodemasked = comparemode & DELAY2B_CTRL_CMPMODE2_MASK;
        #endif /* (0 != DELAY2B_CTRL_CMPMODE2_SHIFT) */

        #if (DELAY2B_UseControl)
            DELAY2B_CONTROL &= ((uint8)(~DELAY2B_CTRL_CMPMODE2_MASK)); /*Clear existing mode */
            DELAY2B_CONTROL |= comparemodemasked;
        #endif /* (DELAY2B_UseControl) */
    }
    #endif /*DELAY2B_CompareMode2SW */

#endif /* UseOneCompareMode */


#if (!DELAY2B_UsingFixedFunction)


    /*******************************************************************************
    * Function Name: DELAY2B_WriteCounter
    ********************************************************************************
    *
    * Summary:
    *  Writes a new counter value directly to the counter register. This will be
    *  implemented for that currently running period and only that period. This API
    *  is valid only for UDB implementation and not available for fixed function
    *  PWM implementation.
    *
    * Parameters:
    *  counter:  The period new period counter value.
    *
    * Return:
    *  None
    *
    * Side Effects:
    *  The PWM Period will be reloaded when a counter value will be a zero
    *
    *******************************************************************************/
    void DELAY2B_WriteCounter(uint8 counter) \
                                       
    {
        CY_SET_REG8(DELAY2B_COUNTER_LSB_PTR, counter);
    }


    /*******************************************************************************
    * Function Name: DELAY2B_ReadCounter
    ********************************************************************************
    *
    * Summary:
    *  This function returns the current value of the counter.  It doesn't matter
    *  if the counter is enabled or running.
    *
    * Parameters:
    *  None
    *
    * Return:
    *  The current value of the counter.
    *
    *******************************************************************************/
    uint8 DELAY2B_ReadCounter(void) 
    {
        /* Force capture by reading Accumulator */
        /* Must first do a software capture to be able to read the counter */
        /* It is up to the user code to make sure there isn't already captured data in the FIFO */
          (void)CY_GET_REG8(DELAY2B_COUNTERCAP_LSB_PTR_8BIT);

        /* Read the data from the FIFO */
        return (CY_GET_REG8(DELAY2B_CAPTURE_LSB_PTR));
    }

    #if (DELAY2B_UseStatus)


        /*******************************************************************************
        * Function Name: DELAY2B_ClearFIFO
        ********************************************************************************
        *
        * Summary:
        *  This function clears all capture data from the capture FIFO
        *
        * Parameters:
        *  None
        *
        * Return:
        *  None
        *
        *******************************************************************************/
        void DELAY2B_ClearFIFO(void) 
        {
            while(0u != (DELAY2B_ReadStatusRegister() & DELAY2B_STATUS_FIFONEMPTY))
            {
                (void)DELAY2B_ReadCapture();
            }
        }

    #endif /* DELAY2B_UseStatus */

#endif /* !DELAY2B_UsingFixedFunction */


/*******************************************************************************
* Function Name: DELAY2B_WritePeriod
********************************************************************************
*
* Summary:
*  This function is used to change the period of the counter.  The new period
*  will be loaded the next time terminal count is detected.
*
* Parameters:
*  period:  Period value. May be between 1 and (2^Resolution)-1.  A value of 0
*           will result in the counter remaining at zero.
*
* Return:
*  None
*
*******************************************************************************/
void DELAY2B_WritePeriod(uint8 period) 
{
    #if(DELAY2B_UsingFixedFunction)
        CY_SET_REG16(DELAY2B_PERIOD_LSB_PTR, (uint16)period);
    #else
        CY_SET_REG8(DELAY2B_PERIOD_LSB_PTR, period);
    #endif /* (DELAY2B_UsingFixedFunction) */
}

#if (DELAY2B_UseOneCompareMode)


    /*******************************************************************************
    * Function Name: DELAY2B_WriteCompare
    ********************************************************************************
    *
    * Summary:
    *  This funtion is used to change the compare1 value when the PWM is in Dither
    *  mode. The compare output will reflect the new value on the next UDB clock.
    *  The compare output will be driven high when the present counter value is
    *  compared to the compare value based on the compare mode defined in
    *  Dither Mode.
    *
    * Parameters:
    *  compare:  New compare value.
    *
    * Return:
    *  None
    *
    * Side Effects:
    *  This function is only available if the PWM mode parameter is set to
    *  Dither Mode, Center Aligned Mode or One Output Mode
    *
    *******************************************************************************/
    void DELAY2B_WriteCompare(uint8 compare) \
                                       
    {
        #if(DELAY2B_UsingFixedFunction)
            CY_SET_REG16(DELAY2B_COMPARE1_LSB_PTR, (uint16)compare);
        #else
            CY_SET_REG8(DELAY2B_COMPARE1_LSB_PTR, compare);
        #endif /* (DELAY2B_UsingFixedFunction) */

        #if (DELAY2B_PWMMode == DELAY2B__B_PWM__DITHER)
            #if(DELAY2B_UsingFixedFunction)
                CY_SET_REG16(DELAY2B_COMPARE2_LSB_PTR, (uint16)(compare + 1u));
            #else
                CY_SET_REG8(DELAY2B_COMPARE2_LSB_PTR, (compare + 1u));
            #endif /* (DELAY2B_UsingFixedFunction) */
        #endif /* (DELAY2B_PWMMode == DELAY2B__B_PWM__DITHER) */
    }


#else


    /*******************************************************************************
    * Function Name: DELAY2B_WriteCompare1
    ********************************************************************************
    *
    * Summary:
    *  This funtion is used to change the compare1 value.  The compare output will
    *  reflect the new value on the next UDB clock.  The compare output will be
    *  driven high when the present counter value is less than or less than or
    *  equal to the compare register, depending on the mode.
    *
    * Parameters:
    *  compare:  New compare value.
    *
    * Return:
    *  None
    *
    *******************************************************************************/
    void DELAY2B_WriteCompare1(uint8 compare) \
                                        
    {
        #if(DELAY2B_UsingFixedFunction)
            CY_SET_REG16(DELAY2B_COMPARE1_LSB_PTR, (uint16)compare);
        #else
            CY_SET_REG8(DELAY2B_COMPARE1_LSB_PTR, compare);
        #endif /* (DELAY2B_UsingFixedFunction) */
    }


    /*******************************************************************************
    * Function Name: DELAY2B_WriteCompare2
    ********************************************************************************
    *
    * Summary:
    *  This funtion is used to change the compare value, for compare1 output.
    *  The compare output will reflect the new value on the next UDB clock.
    *  The compare output will be driven high when the present counter value is
    *  less than or less than or equal to the compare register, depending on the
    *  mode.
    *
    * Parameters:
    *  compare:  New compare value.
    *
    * Return:
    *  None
    *
    *******************************************************************************/
    void DELAY2B_WriteCompare2(uint8 compare) \
                                        
    {
        #if(DELAY2B_UsingFixedFunction)
            CY_SET_REG16(DELAY2B_COMPARE2_LSB_PTR, compare);
        #else
            CY_SET_REG8(DELAY2B_COMPARE2_LSB_PTR, compare);
        #endif /* (DELAY2B_UsingFixedFunction) */
    }
#endif /* UseOneCompareMode */

#if (DELAY2B_DeadBandUsed)


    /*******************************************************************************
    * Function Name: DELAY2B_WriteDeadTime
    ********************************************************************************
    *
    * Summary:
    *  This function writes the dead-band counts to the corresponding register
    *
    * Parameters:
    *  deadtime:  Number of counts for dead time
    *
    * Return:
    *  None
    *
    *******************************************************************************/
    void DELAY2B_WriteDeadTime(uint8 deadtime) 
    {
        /* If using the Dead Band 1-255 mode then just write the register */
        #if(!DELAY2B_DeadBand2_4)
            CY_SET_REG8(DELAY2B_DEADBAND_COUNT_PTR, deadtime);
        #else
            /* Otherwise the data has to be masked and offset */
            /* Clear existing data */
            DELAY2B_DEADBAND_COUNT &= ((uint8)(~DELAY2B_DEADBAND_COUNT_MASK));

            /* Set new dead time */
            #if(DELAY2B_DEADBAND_COUNT_SHIFT)
                DELAY2B_DEADBAND_COUNT |= ((uint8)((uint8)deadtime << DELAY2B_DEADBAND_COUNT_SHIFT)) &
                                                    DELAY2B_DEADBAND_COUNT_MASK;
            #else
                DELAY2B_DEADBAND_COUNT |= deadtime & DELAY2B_DEADBAND_COUNT_MASK;
            #endif /* (DELAY2B_DEADBAND_COUNT_SHIFT) */

        #endif /* (!DELAY2B_DeadBand2_4) */
    }


    /*******************************************************************************
    * Function Name: DELAY2B_ReadDeadTime
    ********************************************************************************
    *
    * Summary:
    *  This function reads the dead-band counts from the corresponding register
    *
    * Parameters:
    *  None
    *
    * Return:
    *  Dead Band Counts
    *
    *******************************************************************************/
    uint8 DELAY2B_ReadDeadTime(void) 
    {
        /* If using the Dead Band 1-255 mode then just read the register */
        #if(!DELAY2B_DeadBand2_4)
            return (CY_GET_REG8(DELAY2B_DEADBAND_COUNT_PTR));
        #else

            /* Otherwise the data has to be masked and offset */
            #if(DELAY2B_DEADBAND_COUNT_SHIFT)
                return ((uint8)(((uint8)(DELAY2B_DEADBAND_COUNT & DELAY2B_DEADBAND_COUNT_MASK)) >>
                                                                           DELAY2B_DEADBAND_COUNT_SHIFT));
            #else
                return (DELAY2B_DEADBAND_COUNT & DELAY2B_DEADBAND_COUNT_MASK);
            #endif /* (DELAY2B_DEADBAND_COUNT_SHIFT) */
        #endif /* (!DELAY2B_DeadBand2_4) */
    }
#endif /* DeadBandUsed */

#if (DELAY2B_UseStatus || DELAY2B_UsingFixedFunction)


    /*******************************************************************************
    * Function Name: DELAY2B_SetInterruptMode
    ********************************************************************************
    *
    * Summary:
    *  This function configures the interrupts mask control of theinterrupt
    *  source status register.
    *
    * Parameters:
    *  uint8 interruptMode: Bit field containing the interrupt sources enabled
    *
    * Return:
    *  None
    *
    *******************************************************************************/
    void DELAY2B_SetInterruptMode(uint8 interruptMode) 
    {
        CY_SET_REG8(DELAY2B_STATUS_MASK_PTR, interruptMode);
    }


    /*******************************************************************************
    * Function Name: DELAY2B_ReadStatusRegister
    ********************************************************************************
    *
    * Summary:
    *  This function returns the current state of the status register.
    *
    * Parameters:
    *  None
    *
    * Return:
    *  uint8 : Current status register value. The status register bits are:
    *  [7:6] : Unused(0)
    *  [5]   : Kill event output
    *  [4]   : FIFO not empty
    *  [3]   : FIFO full
    *  [2]   : Terminal count
    *  [1]   : Compare output 2
    *  [0]   : Compare output 1
    *
    *******************************************************************************/
    uint8 DELAY2B_ReadStatusRegister(void) 
    {
        return (CY_GET_REG8(DELAY2B_STATUS_PTR));
    }

#endif /* (DELAY2B_UseStatus || DELAY2B_UsingFixedFunction) */


#if (DELAY2B_UseControl)


    /*******************************************************************************
    * Function Name: DELAY2B_ReadControlRegister
    ********************************************************************************
    *
    * Summary:
    *  Returns the current state of the control register. This API is available
    *  only if the control register is not removed.
    *
    * Parameters:
    *  None
    *
    * Return:
    *  uint8 : Current control register value
    *
    *******************************************************************************/
    uint8 DELAY2B_ReadControlRegister(void) 
    {
        uint8 result;

        result = CY_GET_REG8(DELAY2B_CONTROL_PTR);
        return (result);
    }


    /*******************************************************************************
    * Function Name: DELAY2B_WriteControlRegister
    ********************************************************************************
    *
    * Summary:
    *  Sets the bit field of the control register. This API is available only if
    *  the control register is not removed.
    *
    * Parameters:
    *  uint8 control: Control register bit field, The status register bits are:
    *  [7]   : PWM Enable
    *  [6]   : Reset
    *  [5:3] : Compare Mode2
    *  [2:0] : Compare Mode2
    *
    * Return:
    *  None
    *
    *******************************************************************************/
    void DELAY2B_WriteControlRegister(uint8 control) 
    {
        CY_SET_REG8(DELAY2B_CONTROL_PTR, control);
    }

#endif /* (DELAY2B_UseControl) */


#if (!DELAY2B_UsingFixedFunction)


    /*******************************************************************************
    * Function Name: DELAY2B_ReadCapture
    ********************************************************************************
    *
    * Summary:
    *  Reads the capture value from the capture FIFO.
    *
    * Parameters:
    *  None
    *
    * Return:
    *  uint8/uint16: The current capture value
    *
    *******************************************************************************/
    uint8 DELAY2B_ReadCapture(void) 
    {
        return (CY_GET_REG8(DELAY2B_CAPTURE_LSB_PTR));
    }

#endif /* (!DELAY2B_UsingFixedFunction) */


#if (DELAY2B_UseOneCompareMode)


    /*******************************************************************************
    * Function Name: DELAY2B_ReadCompare
    ********************************************************************************
    *
    * Summary:
    *  Reads the compare value for the compare output when the PWM Mode parameter is
    *  set to Dither mode, Center Aligned mode, or One Output mode.
    *
    * Parameters:
    *  None
    *
    * Return:
    *  uint8/uint16: Current compare value
    *
    *******************************************************************************/
    uint8 DELAY2B_ReadCompare(void) 
    {
        #if(DELAY2B_UsingFixedFunction)
            return ((uint8)CY_GET_REG16(DELAY2B_COMPARE1_LSB_PTR));
        #else
            return (CY_GET_REG8(DELAY2B_COMPARE1_LSB_PTR));
        #endif /* (DELAY2B_UsingFixedFunction) */
    }

#else


    /*******************************************************************************
    * Function Name: DELAY2B_ReadCompare1
    ********************************************************************************
    *
    * Summary:
    *  Reads the compare value for the compare1 output.
    *
    * Parameters:
    *  None
    *
    * Return:
    *  uint8/uint16: Current compare value.
    *
    *******************************************************************************/
    uint8 DELAY2B_ReadCompare1(void) 
    {
        return (CY_GET_REG8(DELAY2B_COMPARE1_LSB_PTR));
    }


    /*******************************************************************************
    * Function Name: DELAY2B_ReadCompare2
    ********************************************************************************
    *
    * Summary:
    *  Reads the compare value for the compare2 output.
    *
    * Parameters:
    *  None
    *
    * Return:
    *  uint8/uint16: Current compare value.
    *
    *******************************************************************************/
    uint8 DELAY2B_ReadCompare2(void) 
    {
        return (CY_GET_REG8(DELAY2B_COMPARE2_LSB_PTR));
    }

#endif /* (DELAY2B_UseOneCompareMode) */


/*******************************************************************************
* Function Name: DELAY2B_ReadPeriod
********************************************************************************
*
* Summary:
*  Reads the period value used by the PWM hardware.
*
* Parameters:
*  None
*
* Return:
*  uint8/16: Period value
*
*******************************************************************************/
uint8 DELAY2B_ReadPeriod(void) 
{
    #if(DELAY2B_UsingFixedFunction)
        return ((uint8)CY_GET_REG16(DELAY2B_PERIOD_LSB_PTR));
    #else
        return (CY_GET_REG8(DELAY2B_PERIOD_LSB_PTR));
    #endif /* (DELAY2B_UsingFixedFunction) */
}

#if ( DELAY2B_KillModeMinTime)


    /*******************************************************************************
    * Function Name: DELAY2B_WriteKillTime
    ********************************************************************************
    *
    * Summary:
    *  Writes the kill time value used by the hardware when the Kill Mode
    *  is set to Minimum Time.
    *
    * Parameters:
    *  uint8: Minimum Time kill counts
    *
    * Return:
    *  None
    *
    *******************************************************************************/
    void DELAY2B_WriteKillTime(uint8 killtime) 
    {
        CY_SET_REG8(DELAY2B_KILLMODEMINTIME_PTR, killtime);
    }


    /*******************************************************************************
    * Function Name: DELAY2B_ReadKillTime
    ********************************************************************************
    *
    * Summary:
    *  Reads the kill time value used by the hardware when the Kill Mode is set
    *  to Minimum Time.
    *
    * Parameters:
    *  None
    *
    * Return:
    *  uint8: The current Minimum Time kill counts
    *
    *******************************************************************************/
    uint8 DELAY2B_ReadKillTime(void) 
    {
        return (CY_GET_REG8(DELAY2B_KILLMODEMINTIME_PTR));
    }

#endif /* ( DELAY2B_KillModeMinTime) */

/* [] END OF FILE */
