/*******************************************************************************
* File Name: EPWM2A.h  
* Version 2.20
*
* Description:
*  This file contains Pin function prototypes and register defines
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_PINS_EPWM2A_H) /* Pins EPWM2A_H */
#define CY_PINS_EPWM2A_H

#include "cytypes.h"
#include "cyfitter.h"
#include "cypins.h"
#include "EPWM2A_aliases.h"

/* APIs are not generated for P15[7:6] */
#if !(CY_PSOC5A &&\
	 EPWM2A__PORT == 15 && ((EPWM2A__MASK & 0xC0) != 0))


/***************************************
*        Function Prototypes             
***************************************/    

/**
* \addtogroup group_general
* @{
*/
void    EPWM2A_Write(uint8 value);
void    EPWM2A_SetDriveMode(uint8 mode);
uint8   EPWM2A_ReadDataReg(void);
uint8   EPWM2A_Read(void);
void    EPWM2A_SetInterruptMode(uint16 position, uint16 mode);
uint8   EPWM2A_ClearInterrupt(void);
/** @} general */

/***************************************
*           API Constants        
***************************************/
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup driveMode Drive mode constants
     * \brief Constants to be passed as "mode" parameter in the EPWM2A_SetDriveMode() function.
     *  @{
     */
        #define EPWM2A_DM_ALG_HIZ         PIN_DM_ALG_HIZ
        #define EPWM2A_DM_DIG_HIZ         PIN_DM_DIG_HIZ
        #define EPWM2A_DM_RES_UP          PIN_DM_RES_UP
        #define EPWM2A_DM_RES_DWN         PIN_DM_RES_DWN
        #define EPWM2A_DM_OD_LO           PIN_DM_OD_LO
        #define EPWM2A_DM_OD_HI           PIN_DM_OD_HI
        #define EPWM2A_DM_STRONG          PIN_DM_STRONG
        #define EPWM2A_DM_RES_UPDWN       PIN_DM_RES_UPDWN
    /** @} driveMode */
/** @} group_constants */
    
/* Digital Port Constants */
#define EPWM2A_MASK               EPWM2A__MASK
#define EPWM2A_SHIFT              EPWM2A__SHIFT
#define EPWM2A_WIDTH              1u

/* Interrupt constants */
#if defined(EPWM2A__INTSTAT)
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup intrMode Interrupt constants
     * \brief Constants to be passed as "mode" parameter in EPWM2A_SetInterruptMode() function.
     *  @{
     */
        #define EPWM2A_INTR_NONE      (uint16)(0x0000u)
        #define EPWM2A_INTR_RISING    (uint16)(0x0001u)
        #define EPWM2A_INTR_FALLING   (uint16)(0x0002u)
        #define EPWM2A_INTR_BOTH      (uint16)(0x0003u) 
    /** @} intrMode */
/** @} group_constants */

    #define EPWM2A_INTR_MASK      (0x01u) 
#endif /* (EPWM2A__INTSTAT) */


/***************************************
*             Registers        
***************************************/

/* Main Port Registers */
/* Pin State */
#define EPWM2A_PS                     (* (reg8 *) EPWM2A__PS)
/* Data Register */
#define EPWM2A_DR                     (* (reg8 *) EPWM2A__DR)
/* Port Number */
#define EPWM2A_PRT_NUM                (* (reg8 *) EPWM2A__PRT) 
/* Connect to Analog Globals */                                                  
#define EPWM2A_AG                     (* (reg8 *) EPWM2A__AG)                       
/* Analog MUX bux enable */
#define EPWM2A_AMUX                   (* (reg8 *) EPWM2A__AMUX) 
/* Bidirectional Enable */                                                        
#define EPWM2A_BIE                    (* (reg8 *) EPWM2A__BIE)
/* Bit-mask for Aliased Register Access */
#define EPWM2A_BIT_MASK               (* (reg8 *) EPWM2A__BIT_MASK)
/* Bypass Enable */
#define EPWM2A_BYP                    (* (reg8 *) EPWM2A__BYP)
/* Port wide control signals */                                                   
#define EPWM2A_CTL                    (* (reg8 *) EPWM2A__CTL)
/* Drive Modes */
#define EPWM2A_DM0                    (* (reg8 *) EPWM2A__DM0) 
#define EPWM2A_DM1                    (* (reg8 *) EPWM2A__DM1)
#define EPWM2A_DM2                    (* (reg8 *) EPWM2A__DM2) 
/* Input Buffer Disable Override */
#define EPWM2A_INP_DIS                (* (reg8 *) EPWM2A__INP_DIS)
/* LCD Common or Segment Drive */
#define EPWM2A_LCD_COM_SEG            (* (reg8 *) EPWM2A__LCD_COM_SEG)
/* Enable Segment LCD */
#define EPWM2A_LCD_EN                 (* (reg8 *) EPWM2A__LCD_EN)
/* Slew Rate Control */
#define EPWM2A_SLW                    (* (reg8 *) EPWM2A__SLW)

/* DSI Port Registers */
/* Global DSI Select Register */
#define EPWM2A_PRTDSI__CAPS_SEL       (* (reg8 *) EPWM2A__PRTDSI__CAPS_SEL) 
/* Double Sync Enable */
#define EPWM2A_PRTDSI__DBL_SYNC_IN    (* (reg8 *) EPWM2A__PRTDSI__DBL_SYNC_IN) 
/* Output Enable Select Drive Strength */
#define EPWM2A_PRTDSI__OE_SEL0        (* (reg8 *) EPWM2A__PRTDSI__OE_SEL0) 
#define EPWM2A_PRTDSI__OE_SEL1        (* (reg8 *) EPWM2A__PRTDSI__OE_SEL1) 
/* Port Pin Output Select Registers */
#define EPWM2A_PRTDSI__OUT_SEL0       (* (reg8 *) EPWM2A__PRTDSI__OUT_SEL0) 
#define EPWM2A_PRTDSI__OUT_SEL1       (* (reg8 *) EPWM2A__PRTDSI__OUT_SEL1) 
/* Sync Output Enable Registers */
#define EPWM2A_PRTDSI__SYNC_OUT       (* (reg8 *) EPWM2A__PRTDSI__SYNC_OUT) 

/* SIO registers */
#if defined(EPWM2A__SIO_CFG)
    #define EPWM2A_SIO_HYST_EN        (* (reg8 *) EPWM2A__SIO_HYST_EN)
    #define EPWM2A_SIO_REG_HIFREQ     (* (reg8 *) EPWM2A__SIO_REG_HIFREQ)
    #define EPWM2A_SIO_CFG            (* (reg8 *) EPWM2A__SIO_CFG)
    #define EPWM2A_SIO_DIFF           (* (reg8 *) EPWM2A__SIO_DIFF)
#endif /* (EPWM2A__SIO_CFG) */

/* Interrupt Registers */
#if defined(EPWM2A__INTSTAT)
    #define EPWM2A_INTSTAT            (* (reg8 *) EPWM2A__INTSTAT)
    #define EPWM2A_SNAP               (* (reg8 *) EPWM2A__SNAP)
    
	#define EPWM2A_0_INTTYPE_REG 		(* (reg8 *) EPWM2A__0__INTTYPE)
#endif /* (EPWM2A__INTSTAT) */

#endif /* CY_PSOC5A... */

#endif /*  CY_PINS_EPWM2A_H */


/* [] END OF FILE */
