/*******************************************************************************
* File Name: PSFB_1_internal_pwm.h  
* Version 2.40
*
* Description:
*  Contains the prototypes and constants for the functions available to the 
*  PWM user module.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
********************************************************************************/

#if !defined(CY_PWM_PSFB_1_internal_pwm_H)
#define CY_PWM_PSFB_1_internal_pwm_H

#include "cytypes.h"
#include "cyfitter.h"
#include "CyLib.h" /* For CyEnterCriticalSection() and CyExitCriticalSection() functions */

extern uint8 PSFB_1_internal_pwm_initVar;


/***************************************
* Conditional Compilation Parameters
***************************************/
#define PSFB_1_internal_pwm_Resolution 8u
#define PSFB_1_internal_pwm_UsingFixedFunction 0u
#define PSFB_1_internal_pwm_DeadBandMode 0u
#define PSFB_1_internal_pwm_KillModeMinTime 0u
#define PSFB_1_internal_pwm_KillMode 0u
#define PSFB_1_internal_pwm_PWMMode 0u
#define PSFB_1_internal_pwm_PWMModeIsCenterAligned 0u
#define PSFB_1_internal_pwm_DeadBandUsed 0u
#define PSFB_1_internal_pwm_DeadBand2_4 0u
#if !defined(PSFB_1_internal_pwm_PWMUDB_sSTSReg_stsreg__REMOVED)
    #define PSFB_1_internal_pwm_UseStatus 0u
#else
    #define PSFB_1_internal_pwm_UseStatus 0u
#endif /* !defined(PSFB_1_internal_pwm_PWMUDB_sSTSReg_stsreg__REMOVED) */
#if !defined(PSFB_1_internal_pwm_PWMUDB_sCTRLReg_ctrlreg__REMOVED)
    #define PSFB_1_internal_pwm_UseControl 1u
#else
    #define PSFB_1_internal_pwm_UseControl 0u
#endif /* !defined(PSFB_1_internal_pwm_PWMUDB_sCTRLReg_ctrlreg__REMOVED) */
#define PSFB_1_internal_pwm_UseOneCompareMode 1u
#define PSFB_1_internal_pwm_MinimumKillTime 1u
#define PSFB_1_internal_pwm_EnableMode 0u

#define PSFB_1_internal_pwm_CompareMode1SW 0u
#define PSFB_1_internal_pwm_CompareMode2SW 0u

/* Check to see if required defines such as CY_PSOC5LP are available */
/* They are defined starting with cy_boot v3.0 */
#if !defined (CY_PSOC5LP)
    #error Component PWM_v2_40 requires cy_boot v3.0 or later
#endif /* (CY_ PSOC5LP) */

/* Use Kill Mode Enumerated Types */
#define PSFB_1_internal_pwm__B_PWM__DISABLED 0
#define PSFB_1_internal_pwm__B_PWM__ASYNCHRONOUS 1
#define PSFB_1_internal_pwm__B_PWM__SINGLECYCLE 2
#define PSFB_1_internal_pwm__B_PWM__LATCHED 3
#define PSFB_1_internal_pwm__B_PWM__MINTIME 4


/* Use Dead Band Mode Enumerated Types */
#define PSFB_1_internal_pwm__B_PWM__DBMDISABLED 0
#define PSFB_1_internal_pwm__B_PWM__DBM_2_4_CLOCKS 1
#define PSFB_1_internal_pwm__B_PWM__DBM_256_CLOCKS 2


/* Used PWM Mode Enumerated Types */
#define PSFB_1_internal_pwm__B_PWM__ONE_OUTPUT 0
#define PSFB_1_internal_pwm__B_PWM__TWO_OUTPUTS 1
#define PSFB_1_internal_pwm__B_PWM__DUAL_EDGE 2
#define PSFB_1_internal_pwm__B_PWM__CENTER_ALIGN 3
#define PSFB_1_internal_pwm__B_PWM__DITHER 5
#define PSFB_1_internal_pwm__B_PWM__HARDWARESELECT 4


/* Used PWM Compare Mode Enumerated Types */
#define PSFB_1_internal_pwm__B_PWM__LESS_THAN 1
#define PSFB_1_internal_pwm__B_PWM__LESS_THAN_OR_EQUAL 2
#define PSFB_1_internal_pwm__B_PWM__GREATER_THAN 3
#define PSFB_1_internal_pwm__B_PWM__GREATER_THAN_OR_EQUAL_TO 4
#define PSFB_1_internal_pwm__B_PWM__EQUAL 0
#define PSFB_1_internal_pwm__B_PWM__FIRMWARE 5



/***************************************
* Data Struct Definition
***************************************/


/**************************************************************************
 * Sleep Wakeup Backup structure for PWM Component
 *************************************************************************/
typedef struct
{
    
    uint8 PWMEnableState;
       
    #if(!PSFB_1_internal_pwm_UsingFixedFunction)
        #if (CY_UDB_V0)
            uint8 PWMUdb;               /* PWM Current Counter value  */
            uint8 PWMPeriod;            /* PWM Current Period value   */
            #if (PSFB_1_internal_pwm_UseStatus)
                uint8 InterruptMaskValue;   /* PWM Current Interrupt Mask */
            #endif /* (PSFB_1_internal_pwm_UseStatus) */
            #if(PSFB_1_internal_pwm_UseOneCompareMode)
                uint8 PWMCompareValue;     /* PWM Current Compare value */
            #else
                uint8 PWMCompareValue1;     /* PWM Current Compare value1 */
                uint8 PWMCompareValue2;     /* PWM Current Compare value2 */
            #endif /* (PSFB_1_internal_pwm_UseOneCompareMode) */
            
            /* Backup for Deadband parameters */
            #if(PSFB_1_internal_pwm_DeadBandMode == PSFB_1_internal_pwm__B_PWM__DBM_256_CLOCKS || \
                PSFB_1_internal_pwm_DeadBandMode == PSFB_1_internal_pwm__B_PWM__DBM_2_4_CLOCKS)
                uint8 PWMdeadBandValue; /* Dead Band Counter Current Value */
            #endif /* deadband count is either 2-4 clocks or 256 clocks */
            
            /* Backup Kill Mode Counter*/
            #if(PSFB_1_internal_pwm_KillModeMinTime)
                uint8 PWMKillCounterPeriod; /* Kill Mode period value */
            #endif /* (PSFB_1_internal_pwm_KillModeMinTime) */
            
        #endif /* (CY_UDB_V0) */
        
        #if (CY_UDB_V1)
            uint8 PWMUdb;               /* PWM Current Counter value  */
            #if(!PSFB_1_internal_pwm_PWMModeIsCenterAligned)
                uint8 PWMPeriod;
            #endif /* (!PSFB_1_internal_pwm_PWMModeIsCenterAligned) */
            #if (PSFB_1_internal_pwm_UseStatus)
                uint8 InterruptMaskValue;   /* PWM Current Interrupt Mask */
            #endif /* (PSFB_1_internal_pwm_UseStatus) */
            
            /* Backup for Deadband parameters */
            #if(PSFB_1_internal_pwm_DeadBandMode == PSFB_1_internal_pwm__B_PWM__DBM_256_CLOCKS || \
                PSFB_1_internal_pwm_DeadBandMode == PSFB_1_internal_pwm__B_PWM__DBM_2_4_CLOCKS)
                uint8 PWMdeadBandValue; /* Dead Band Counter Current Value */
            #endif /* deadband count is either 2-4 clocks or 256 clocks */
            
            /* Backup Kill Mode Counter*/
            #if(PSFB_1_internal_pwm_KillModeMinTime)
                uint8 PWMKillCounterPeriod; /* Kill Mode period value */
            #endif /* (PSFB_1_internal_pwm_KillModeMinTime) */
        #endif /* (CY_UDB_V1) */
        
        /* Backup control register */
        #if(PSFB_1_internal_pwm_UseControl)
            uint8 PWMControlRegister; /* PWM Control Register value */
        #endif /* (PSFB_1_internal_pwm_UseControl) */
        
    #endif /* (!PSFB_1_internal_pwm_UsingFixedFunction) */
   
}PSFB_1_internal_pwm_backupStruct;


/***************************************
*        Function Prototypes
 **************************************/
 
void    PSFB_1_internal_pwm_Start(void) ;
void    PSFB_1_internal_pwm_Stop(void) ;

#if (PSFB_1_internal_pwm_UseStatus || PSFB_1_internal_pwm_UsingFixedFunction)
    void  PSFB_1_internal_pwm_SetInterruptMode(uint8 interruptMode) ;
    uint8 PSFB_1_internal_pwm_ReadStatusRegister(void) ;
#endif /* (PSFB_1_internal_pwm_UseStatus || PSFB_1_internal_pwm_UsingFixedFunction) */

#define PSFB_1_internal_pwm_GetInterruptSource() PSFB_1_internal_pwm_ReadStatusRegister()

#if (PSFB_1_internal_pwm_UseControl)
    uint8 PSFB_1_internal_pwm_ReadControlRegister(void) ; 
    void  PSFB_1_internal_pwm_WriteControlRegister(uint8 control) ;
#endif /* (PSFB_1_internal_pwm_UseControl) */

#if (PSFB_1_internal_pwm_UseOneCompareMode)
   #if (PSFB_1_internal_pwm_CompareMode1SW)
       void    PSFB_1_internal_pwm_SetCompareMode(uint8 comparemode) ;
   #endif /* (PSFB_1_internal_pwm_CompareMode1SW) */
#else
    #if (PSFB_1_internal_pwm_CompareMode1SW)
        void    PSFB_1_internal_pwm_SetCompareMode1(uint8 comparemode) ;
    #endif /* (PSFB_1_internal_pwm_CompareMode1SW) */
    #if (PSFB_1_internal_pwm_CompareMode2SW)
        void    PSFB_1_internal_pwm_SetCompareMode2(uint8 comparemode) ;
    #endif /* (PSFB_1_internal_pwm_CompareMode2SW) */
#endif /* (PSFB_1_internal_pwm_UseOneCompareMode) */

#if (!PSFB_1_internal_pwm_UsingFixedFunction)
    uint8   PSFB_1_internal_pwm_ReadCounter(void) ;
    uint8 PSFB_1_internal_pwm_ReadCapture(void) ;
    
	#if (PSFB_1_internal_pwm_UseStatus)
	        void PSFB_1_internal_pwm_ClearFIFO(void) ;
	#endif /* (PSFB_1_internal_pwm_UseStatus) */

    void    PSFB_1_internal_pwm_WriteCounter(uint8 counter) ;
#endif /* (!PSFB_1_internal_pwm_UsingFixedFunction) */

void    PSFB_1_internal_pwm_WritePeriod(uint8 period) ;
uint8 PSFB_1_internal_pwm_ReadPeriod(void) ;

#if (PSFB_1_internal_pwm_UseOneCompareMode)
    void    PSFB_1_internal_pwm_WriteCompare(uint8 compare) ;
    uint8 PSFB_1_internal_pwm_ReadCompare(void) ; 
#else
    void    PSFB_1_internal_pwm_WriteCompare1(uint8 compare) ;
    uint8 PSFB_1_internal_pwm_ReadCompare1(void) ; 
    void    PSFB_1_internal_pwm_WriteCompare2(uint8 compare) ;
    uint8 PSFB_1_internal_pwm_ReadCompare2(void) ; 
#endif /* (PSFB_1_internal_pwm_UseOneCompareMode) */


#if (PSFB_1_internal_pwm_DeadBandUsed)
    void    PSFB_1_internal_pwm_WriteDeadTime(uint8 deadtime) ;
    uint8   PSFB_1_internal_pwm_ReadDeadTime(void) ;
#endif /* (PSFB_1_internal_pwm_DeadBandUsed) */

#if ( PSFB_1_internal_pwm_KillModeMinTime)
    void PSFB_1_internal_pwm_WriteKillTime(uint8 killtime) ;
    uint8 PSFB_1_internal_pwm_ReadKillTime(void) ; 
#endif /* ( PSFB_1_internal_pwm_KillModeMinTime) */

void PSFB_1_internal_pwm_Init(void) ;
void PSFB_1_internal_pwm_Enable(void) ;
void PSFB_1_internal_pwm_Sleep(void) ;
void PSFB_1_internal_pwm_Wakeup(void) ;
void PSFB_1_internal_pwm_SaveConfig(void) ;
void PSFB_1_internal_pwm_RestoreConfig(void) ;


/***************************************
*         Initialization Values
**************************************/
#define PSFB_1_internal_pwm_INIT_PERIOD_VALUE        255u
#define PSFB_1_internal_pwm_INIT_COMPARE_VALUE1      100u
#define PSFB_1_internal_pwm_INIT_COMPARE_VALUE2      50u
#define PSFB_1_internal_pwm_INIT_INTERRUPTS_MODE     (uint8)(((uint8)(0u << PSFB_1_internal_pwm_STATUS_TC_INT_EN_MASK_SHIFT)) | \
                                                  (uint8)((uint8)(0u << PSFB_1_internal_pwm_STATUS_CMP2_INT_EN_MASK_SHIFT)) | \
                                                  (uint8)((uint8)(0u << PSFB_1_internal_pwm_STATUS_CMP1_INT_EN_MASK_SHIFT )) | \
                                                  (uint8)((uint8)(0u << PSFB_1_internal_pwm_STATUS_KILL_INT_EN_MASK_SHIFT )))
#define PSFB_1_internal_pwm_DEFAULT_COMPARE2_MODE    (uint8)((uint8)1u << PSFB_1_internal_pwm_CTRL_CMPMODE2_SHIFT)
#define PSFB_1_internal_pwm_DEFAULT_COMPARE1_MODE    (uint8)((uint8)4u << PSFB_1_internal_pwm_CTRL_CMPMODE1_SHIFT)
#define PSFB_1_internal_pwm_INIT_DEAD_TIME           1u


/********************************
*         Registers
******************************** */

#if (PSFB_1_internal_pwm_UsingFixedFunction)
   #define PSFB_1_internal_pwm_PERIOD_LSB          (*(reg16 *) PSFB_1_internal_pwm_PWMHW__PER0)
   #define PSFB_1_internal_pwm_PERIOD_LSB_PTR      ( (reg16 *) PSFB_1_internal_pwm_PWMHW__PER0)
   #define PSFB_1_internal_pwm_COMPARE1_LSB        (*(reg16 *) PSFB_1_internal_pwm_PWMHW__CNT_CMP0)
   #define PSFB_1_internal_pwm_COMPARE1_LSB_PTR    ( (reg16 *) PSFB_1_internal_pwm_PWMHW__CNT_CMP0)
   #define PSFB_1_internal_pwm_COMPARE2_LSB        0x00u
   #define PSFB_1_internal_pwm_COMPARE2_LSB_PTR    0x00u
   #define PSFB_1_internal_pwm_COUNTER_LSB         (*(reg16 *) PSFB_1_internal_pwm_PWMHW__CNT_CMP0)
   #define PSFB_1_internal_pwm_COUNTER_LSB_PTR     ( (reg16 *) PSFB_1_internal_pwm_PWMHW__CNT_CMP0)
   #define PSFB_1_internal_pwm_CAPTURE_LSB         (*(reg16 *) PSFB_1_internal_pwm_PWMHW__CAP0)
   #define PSFB_1_internal_pwm_CAPTURE_LSB_PTR     ( (reg16 *) PSFB_1_internal_pwm_PWMHW__CAP0)
   #define PSFB_1_internal_pwm_RT1                 (*(reg8 *)  PSFB_1_internal_pwm_PWMHW__RT1)
   #define PSFB_1_internal_pwm_RT1_PTR             ( (reg8 *)  PSFB_1_internal_pwm_PWMHW__RT1)
      
#else
   #if (PSFB_1_internal_pwm_Resolution == 8u) /* 8bit - PWM */
	   
	   #if(PSFB_1_internal_pwm_PWMModeIsCenterAligned)
	       #define PSFB_1_internal_pwm_PERIOD_LSB      (*(reg8 *) PSFB_1_internal_pwm_PWMUDB_sP8_pwmdp_u0__D1_REG)
	       #define PSFB_1_internal_pwm_PERIOD_LSB_PTR   ((reg8 *) PSFB_1_internal_pwm_PWMUDB_sP8_pwmdp_u0__D1_REG)
	   #else
	       #define PSFB_1_internal_pwm_PERIOD_LSB      (*(reg8 *) PSFB_1_internal_pwm_PWMUDB_sP8_pwmdp_u0__F0_REG)
	       #define PSFB_1_internal_pwm_PERIOD_LSB_PTR   ((reg8 *) PSFB_1_internal_pwm_PWMUDB_sP8_pwmdp_u0__F0_REG)
	   #endif /* (PSFB_1_internal_pwm_PWMModeIsCenterAligned) */
	   
	   #define PSFB_1_internal_pwm_COMPARE1_LSB    (*(reg8 *) PSFB_1_internal_pwm_PWMUDB_sP8_pwmdp_u0__D0_REG)
	   #define PSFB_1_internal_pwm_COMPARE1_LSB_PTR ((reg8 *) PSFB_1_internal_pwm_PWMUDB_sP8_pwmdp_u0__D0_REG)
	   #define PSFB_1_internal_pwm_COMPARE2_LSB    (*(reg8 *) PSFB_1_internal_pwm_PWMUDB_sP8_pwmdp_u0__D1_REG)
	   #define PSFB_1_internal_pwm_COMPARE2_LSB_PTR ((reg8 *) PSFB_1_internal_pwm_PWMUDB_sP8_pwmdp_u0__D1_REG)
	   #define PSFB_1_internal_pwm_COUNTERCAP_LSB   (*(reg8 *) PSFB_1_internal_pwm_PWMUDB_sP8_pwmdp_u0__A1_REG)
	   #define PSFB_1_internal_pwm_COUNTERCAP_LSB_PTR ((reg8 *) PSFB_1_internal_pwm_PWMUDB_sP8_pwmdp_u0__A1_REG)
	   #define PSFB_1_internal_pwm_COUNTER_LSB     (*(reg8 *) PSFB_1_internal_pwm_PWMUDB_sP8_pwmdp_u0__A0_REG)
	   #define PSFB_1_internal_pwm_COUNTER_LSB_PTR  ((reg8 *) PSFB_1_internal_pwm_PWMUDB_sP8_pwmdp_u0__A0_REG)
	   #define PSFB_1_internal_pwm_CAPTURE_LSB     (*(reg8 *) PSFB_1_internal_pwm_PWMUDB_sP8_pwmdp_u0__F1_REG)
	   #define PSFB_1_internal_pwm_CAPTURE_LSB_PTR  ((reg8 *) PSFB_1_internal_pwm_PWMUDB_sP8_pwmdp_u0__F1_REG)
   
   #else
   		#if(CY_PSOC3) /* 8-bit address space */	
			#if(PSFB_1_internal_pwm_PWMModeIsCenterAligned)
		       #define PSFB_1_internal_pwm_PERIOD_LSB      (*(reg16 *) PSFB_1_internal_pwm_PWMUDB_sP8_pwmdp_u0__D1_REG)
		       #define PSFB_1_internal_pwm_PERIOD_LSB_PTR   ((reg16 *) PSFB_1_internal_pwm_PWMUDB_sP8_pwmdp_u0__D1_REG)
		    #else
		       #define PSFB_1_internal_pwm_PERIOD_LSB      (*(reg16 *) PSFB_1_internal_pwm_PWMUDB_sP8_pwmdp_u0__F0_REG)
		       #define PSFB_1_internal_pwm_PERIOD_LSB_PTR   ((reg16 *) PSFB_1_internal_pwm_PWMUDB_sP8_pwmdp_u0__F0_REG)
		    #endif /* (PSFB_1_internal_pwm_PWMModeIsCenterAligned) */
		   
		    #define PSFB_1_internal_pwm_COMPARE1_LSB    (*(reg16 *) PSFB_1_internal_pwm_PWMUDB_sP8_pwmdp_u0__D0_REG)
		    #define PSFB_1_internal_pwm_COMPARE1_LSB_PTR ((reg16 *) PSFB_1_internal_pwm_PWMUDB_sP8_pwmdp_u0__D0_REG)
		    #define PSFB_1_internal_pwm_COMPARE2_LSB    (*(reg16 *) PSFB_1_internal_pwm_PWMUDB_sP8_pwmdp_u0__D1_REG)
		    #define PSFB_1_internal_pwm_COMPARE2_LSB_PTR ((reg16 *) PSFB_1_internal_pwm_PWMUDB_sP8_pwmdp_u0__D1_REG)
		    #define PSFB_1_internal_pwm_COUNTERCAP_LSB   (*(reg16 *) PSFB_1_internal_pwm_PWMUDB_sP8_pwmdp_u0__A1_REG)
		    #define PSFB_1_internal_pwm_COUNTERCAP_LSB_PTR ((reg16 *) PSFB_1_internal_pwm_PWMUDB_sP8_pwmdp_u0__A1_REG)
		    #define PSFB_1_internal_pwm_COUNTER_LSB     (*(reg16 *) PSFB_1_internal_pwm_PWMUDB_sP8_pwmdp_u0__A0_REG)
		    #define PSFB_1_internal_pwm_COUNTER_LSB_PTR  ((reg16 *) PSFB_1_internal_pwm_PWMUDB_sP8_pwmdp_u0__A0_REG)
		    #define PSFB_1_internal_pwm_CAPTURE_LSB     (*(reg16 *) PSFB_1_internal_pwm_PWMUDB_sP8_pwmdp_u0__F1_REG)
		    #define PSFB_1_internal_pwm_CAPTURE_LSB_PTR  ((reg16 *) PSFB_1_internal_pwm_PWMUDB_sP8_pwmdp_u0__F1_REG)
		#else
			#if(PSFB_1_internal_pwm_PWMModeIsCenterAligned)
		       #define PSFB_1_internal_pwm_PERIOD_LSB      (*(reg16 *) PSFB_1_internal_pwm_PWMUDB_sP8_pwmdp_u0__16BIT_D1_REG)
		       #define PSFB_1_internal_pwm_PERIOD_LSB_PTR   ((reg16 *) PSFB_1_internal_pwm_PWMUDB_sP8_pwmdp_u0__16BIT_D1_REG)
		    #else
		       #define PSFB_1_internal_pwm_PERIOD_LSB      (*(reg16 *) PSFB_1_internal_pwm_PWMUDB_sP8_pwmdp_u0__16BIT_F0_REG)
		       #define PSFB_1_internal_pwm_PERIOD_LSB_PTR   ((reg16 *) PSFB_1_internal_pwm_PWMUDB_sP8_pwmdp_u0__16BIT_F0_REG)
		    #endif /* (PSFB_1_internal_pwm_PWMModeIsCenterAligned) */
		   
		    #define PSFB_1_internal_pwm_COMPARE1_LSB    (*(reg16 *) PSFB_1_internal_pwm_PWMUDB_sP8_pwmdp_u0__16BIT_D0_REG)
		    #define PSFB_1_internal_pwm_COMPARE1_LSB_PTR ((reg16 *) PSFB_1_internal_pwm_PWMUDB_sP8_pwmdp_u0__16BIT_D0_REG)
		    #define PSFB_1_internal_pwm_COMPARE2_LSB    (*(reg16 *) PSFB_1_internal_pwm_PWMUDB_sP8_pwmdp_u0__16BIT_D1_REG)
		    #define PSFB_1_internal_pwm_COMPARE2_LSB_PTR ((reg16 *) PSFB_1_internal_pwm_PWMUDB_sP8_pwmdp_u0__16BIT_D1_REG)
		    #define PSFB_1_internal_pwm_COUNTERCAP_LSB   (*(reg16 *) PSFB_1_internal_pwm_PWMUDB_sP8_pwmdp_u0__16BIT_A1_REG)
		    #define PSFB_1_internal_pwm_COUNTERCAP_LSB_PTR ((reg16 *) PSFB_1_internal_pwm_PWMUDB_sP8_pwmdp_u0__16BIT_A1_REG)
		    #define PSFB_1_internal_pwm_COUNTER_LSB     (*(reg16 *) PSFB_1_internal_pwm_PWMUDB_sP8_pwmdp_u0__16BIT_A0_REG)
		    #define PSFB_1_internal_pwm_COUNTER_LSB_PTR  ((reg16 *) PSFB_1_internal_pwm_PWMUDB_sP8_pwmdp_u0__16BIT_A0_REG)
		    #define PSFB_1_internal_pwm_CAPTURE_LSB     (*(reg16 *) PSFB_1_internal_pwm_PWMUDB_sP8_pwmdp_u0__16BIT_F1_REG)
		    #define PSFB_1_internal_pwm_CAPTURE_LSB_PTR  ((reg16 *) PSFB_1_internal_pwm_PWMUDB_sP8_pwmdp_u0__16BIT_F1_REG)
		#endif
		
	   #define PSFB_1_internal_pwm_AUX_CONTROLDP1    (*(reg8 *) PSFB_1_internal_pwm_PWMUDB_sP8_pwmdp_u1__DP_AUX_CTL_REG)
       #define PSFB_1_internal_pwm_AUX_CONTROLDP1_PTR  ((reg8 *) PSFB_1_internal_pwm_PWMUDB_sP8_pwmdp_u1__DP_AUX_CTL_REG)

   #endif /* (PSFB_1_internal_pwm_Resolution == 8) */
   
   #define PSFB_1_internal_pwm_AUX_CONTROLDP0      (*(reg8 *) PSFB_1_internal_pwm_PWMUDB_sP8_pwmdp_u0__DP_AUX_CTL_REG)
   #define PSFB_1_internal_pwm_AUX_CONTROLDP0_PTR  ((reg8 *) PSFB_1_internal_pwm_PWMUDB_sP8_pwmdp_u0__DP_AUX_CTL_REG)

#endif /* (PSFB_1_internal_pwm_UsingFixedFunction) */
   
#if(PSFB_1_internal_pwm_KillModeMinTime )
    #define PSFB_1_internal_pwm_KILLMODEMINTIME      (*(reg8 *) PSFB_1_internal_pwm_PWMUDB_sKM_killmodecounterdp_u0__D0_REG)
    #define PSFB_1_internal_pwm_KILLMODEMINTIME_PTR   ((reg8 *) PSFB_1_internal_pwm_PWMUDB_sKM_killmodecounterdp_u0__D0_REG)
    /* Fixed Function Block has no Kill Mode parameters because it is Asynchronous only */
#endif /* (PSFB_1_internal_pwm_KillModeMinTime ) */

#if(PSFB_1_internal_pwm_DeadBandMode == PSFB_1_internal_pwm__B_PWM__DBM_256_CLOCKS)
    #define PSFB_1_internal_pwm_DEADBAND_COUNT      (*(reg8 *) PSFB_1_internal_pwm_PWMUDB_sDB255_deadbandcounterdp_u0__D0_REG)
    #define PSFB_1_internal_pwm_DEADBAND_COUNT_PTR  ((reg8 *) PSFB_1_internal_pwm_PWMUDB_sDB255_deadbandcounterdp_u0__D0_REG)
    #define PSFB_1_internal_pwm_DEADBAND_LSB_PTR    ((reg8 *) PSFB_1_internal_pwm_PWMUDB_sDB255_deadbandcounterdp_u0__A0_REG)
    #define PSFB_1_internal_pwm_DEADBAND_LSB        (*(reg8 *) PSFB_1_internal_pwm_PWMUDB_sDB255_deadbandcounterdp_u0__A0_REG)
#elif(PSFB_1_internal_pwm_DeadBandMode == PSFB_1_internal_pwm__B_PWM__DBM_2_4_CLOCKS)
    /* In Fixed Function Block these bits are in the control blocks control register */
    #if (PSFB_1_internal_pwm_UsingFixedFunction)
        #define PSFB_1_internal_pwm_DEADBAND_COUNT        (*(reg8 *) PSFB_1_internal_pwm_PWMHW__CFG0) 
        #define PSFB_1_internal_pwm_DEADBAND_COUNT_PTR     ((reg8 *) PSFB_1_internal_pwm_PWMHW__CFG0)
        #define PSFB_1_internal_pwm_DEADBAND_COUNT_MASK    (uint8)((uint8)0x03u << PSFB_1_internal_pwm_DEADBAND_COUNT_SHIFT)
        /* As defined by the Register Map as DEADBAND_PERIOD[1:0] in CFG0 */
        #define PSFB_1_internal_pwm_DEADBAND_COUNT_SHIFT   0x06u  
    #else
        /* Lower two bits of the added control register define the count 1-3 */
        #define PSFB_1_internal_pwm_DEADBAND_COUNT        (*(reg8 *) PSFB_1_internal_pwm_PWMUDB_sDB3_SyncCtl_dbctrlreg__CONTROL_REG)
        #define PSFB_1_internal_pwm_DEADBAND_COUNT_PTR     ((reg8 *) PSFB_1_internal_pwm_PWMUDB_sDB3_SyncCtl_dbctrlreg__CONTROL_REG)
        #define PSFB_1_internal_pwm_DEADBAND_COUNT_MASK    (uint8)((uint8)0x03u << PSFB_1_internal_pwm_DEADBAND_COUNT_SHIFT) 
        /* As defined by the verilog implementation of the Control Register */
        #define PSFB_1_internal_pwm_DEADBAND_COUNT_SHIFT   0x00u 
    #endif /* (PSFB_1_internal_pwm_UsingFixedFunction) */
#endif /* (PSFB_1_internal_pwm_DeadBandMode == PSFB_1_internal_pwm__B_PWM__DBM_256_CLOCKS) */



#if (PSFB_1_internal_pwm_UsingFixedFunction)
    #define PSFB_1_internal_pwm_STATUS                (*(reg8 *) PSFB_1_internal_pwm_PWMHW__SR0)
    #define PSFB_1_internal_pwm_STATUS_PTR            ((reg8 *) PSFB_1_internal_pwm_PWMHW__SR0)
    #define PSFB_1_internal_pwm_STATUS_MASK           (*(reg8 *) PSFB_1_internal_pwm_PWMHW__SR0)
    #define PSFB_1_internal_pwm_STATUS_MASK_PTR       ((reg8 *) PSFB_1_internal_pwm_PWMHW__SR0)
    #define PSFB_1_internal_pwm_CONTROL               (*(reg8 *) PSFB_1_internal_pwm_PWMHW__CFG0)
    #define PSFB_1_internal_pwm_CONTROL_PTR           ((reg8 *) PSFB_1_internal_pwm_PWMHW__CFG0)    
    #define PSFB_1_internal_pwm_CONTROL2              (*(reg8 *) PSFB_1_internal_pwm_PWMHW__CFG1)    
    #if(CY_PSOC3 || CY_PSOC5LP)
        #define PSFB_1_internal_pwm_CONTROL3              (*(reg8 *) PSFB_1_internal_pwm_PWMHW__CFG2)
    #endif /* (CY_PSOC3 || CY_PSOC5LP) */
    #define PSFB_1_internal_pwm_GLOBAL_ENABLE         (*(reg8 *) PSFB_1_internal_pwm_PWMHW__PM_ACT_CFG)
    #define PSFB_1_internal_pwm_GLOBAL_ENABLE_PTR       ( (reg8 *) PSFB_1_internal_pwm_PWMHW__PM_ACT_CFG)
    #define PSFB_1_internal_pwm_GLOBAL_STBY_ENABLE      (*(reg8 *) PSFB_1_internal_pwm_PWMHW__PM_STBY_CFG)
    #define PSFB_1_internal_pwm_GLOBAL_STBY_ENABLE_PTR  ( (reg8 *) PSFB_1_internal_pwm_PWMHW__PM_STBY_CFG)
  
  
    /***********************************
    *          Constants
    ***********************************/

    /* Fixed Function Block Chosen */
    #define PSFB_1_internal_pwm_BLOCK_EN_MASK          PSFB_1_internal_pwm_PWMHW__PM_ACT_MSK
    #define PSFB_1_internal_pwm_BLOCK_STBY_EN_MASK     PSFB_1_internal_pwm_PWMHW__PM_STBY_MSK 
    /* Control Register definitions */
    #define PSFB_1_internal_pwm_CTRL_ENABLE_SHIFT      0x00u
    
    #if(CY_PSOC5A)
        #define PSFB_1_internal_pwm_CTRL_CMPMODE1_SHIFT    0x01u   /* As defined by Register map as MODE_CFG bits in CFG1*/
    #endif /* (CY_PSOC5A) */
    #if(CY_PSOC3 || CY_PSOC5LP)
        #define PSFB_1_internal_pwm_CTRL_CMPMODE1_SHIFT    0x04u  /* As defined by Register map as MODE_CFG bits in CFG2*/
    #endif /* (CY_PSOC3 || CY_PSOC5LP) */
    
    #define PSFB_1_internal_pwm_CTRL_DEAD_TIME_SHIFT   0x06u   /* As defined by Register map */
    /* Fixed Function Block Only CFG register bit definitions */
    #define PSFB_1_internal_pwm_CFG0_MODE              0x02u   /*  Set to compare mode */
    /* #define PSFB_1_internal_pwm_CFG0_ENABLE            0x01u */  /* Enable the block to run */
    #define PSFB_1_internal_pwm_CFG0_DB                0x20u   /* As defined by Register map as DB bit in CFG0 */

    /* Control Register Bit Masks */
    #define PSFB_1_internal_pwm_CTRL_ENABLE            (uint8)((uint8)0x01u << PSFB_1_internal_pwm_CTRL_ENABLE_SHIFT)
    #define PSFB_1_internal_pwm_CTRL_RESET             (uint8)((uint8)0x01u << PSFB_1_internal_pwm_CTRL_RESET_SHIFT)
    #define PSFB_1_internal_pwm_CTRL_CMPMODE2_MASK     (uint8)((uint8)0x07u << PSFB_1_internal_pwm_CTRL_CMPMODE2_SHIFT)
    #if(CY_PSOC5A)
        #define PSFB_1_internal_pwm_CTRL_CMPMODE1_MASK     (uint8)((uint8)0x07u << PSFB_1_internal_pwm_CTRL_CMPMODE1_SHIFT)
    #endif /* (CY_PSOC5A) */
    #if(CY_PSOC3 || CY_PSOC5LP)
        #define PSFB_1_internal_pwm_CTRL_CMPMODE1_MASK     (uint8)((uint8)0x07u << PSFB_1_internal_pwm_CTRL_CMPMODE1_SHIFT)
    #endif /* (CY_PSOC3 || CY_PSOC5LP) */
    
    /* Control2 Register Bit Masks */
    /* As defined in Register Map, Part of the TMRX_CFG1 register */
    #define PSFB_1_internal_pwm_CTRL2_IRQ_SEL_SHIFT    0x00u       
    #define PSFB_1_internal_pwm_CTRL2_IRQ_SEL          (uint8)((uint8)0x01u << PSFB_1_internal_pwm_CTRL2_IRQ_SEL_SHIFT)  
    
    /* Status Register Bit Locations */
    #define PSFB_1_internal_pwm_STATUS_TC_SHIFT            0x07u   /* As defined by Register map as TC in SR0 */
    #define PSFB_1_internal_pwm_STATUS_CMP1_SHIFT          0x06u   /* As defined by the Register map as CAP_CMP in SR0 */
    
    /* Status Register Interrupt Enable Bit Locations */
    #define PSFB_1_internal_pwm_STATUS_KILL_INT_EN_MASK_SHIFT          (0x00u)    
    #define PSFB_1_internal_pwm_STATUS_TC_INT_EN_MASK_SHIFT            (PSFB_1_internal_pwm_STATUS_TC_SHIFT - 4u)
    #define PSFB_1_internal_pwm_STATUS_CMP2_INT_EN_MASK_SHIFT          (0x00u)  
    #define PSFB_1_internal_pwm_STATUS_CMP1_INT_EN_MASK_SHIFT          (PSFB_1_internal_pwm_STATUS_CMP1_SHIFT - 4u)
    
    /* Status Register Bit Masks */
    #define PSFB_1_internal_pwm_STATUS_TC              (uint8)((uint8)0x01u << PSFB_1_internal_pwm_STATUS_TC_SHIFT)
    #define PSFB_1_internal_pwm_STATUS_CMP1            (uint8)((uint8)0x01u << PSFB_1_internal_pwm_STATUS_CMP1_SHIFT)
    
    /* Status Register Interrupt Bit Masks*/
    #define PSFB_1_internal_pwm_STATUS_TC_INT_EN_MASK              (uint8)((uint8)PSFB_1_internal_pwm_STATUS_TC >> 4u)
    #define PSFB_1_internal_pwm_STATUS_CMP1_INT_EN_MASK            (uint8)((uint8)PSFB_1_internal_pwm_STATUS_CMP1 >> 4u)
    
    /*RT1 Synch Constants: Applicable for PSoC3 and PSoC5LP*/
    #define PSFB_1_internal_pwm_RT1_SHIFT             0x04u
    #define PSFB_1_internal_pwm_RT1_MASK              (uint8)((uint8)0x03u << PSFB_1_internal_pwm_RT1_SHIFT)/* Sync TC and CMP bit masks */
    #define PSFB_1_internal_pwm_SYNC                  (uint8)((uint8)0x03u << PSFB_1_internal_pwm_RT1_SHIFT)
    #define PSFB_1_internal_pwm_SYNCDSI_SHIFT         0x00u
    #define PSFB_1_internal_pwm_SYNCDSI_MASK          (uint8)((uint8)0x0Fu << PSFB_1_internal_pwm_SYNCDSI_SHIFT) /* Sync all DSI inputs */
    #define PSFB_1_internal_pwm_SYNCDSI_EN            (uint8)((uint8)0x0Fu << PSFB_1_internal_pwm_SYNCDSI_SHIFT) /* Sync all DSI inputs */
    

#else
    #define PSFB_1_internal_pwm_STATUS                (*(reg8 *) PSFB_1_internal_pwm_PWMUDB_sSTSReg_rstSts_stsreg__STATUS_REG )
    #define PSFB_1_internal_pwm_STATUS_PTR            ((reg8 *) PSFB_1_internal_pwm_PWMUDB_sSTSReg_rstSts_stsreg__STATUS_REG )
    #define PSFB_1_internal_pwm_STATUS_MASK           (*(reg8 *) PSFB_1_internal_pwm_PWMUDB_sSTSReg_rstSts_stsreg__MASK_REG)
    #define PSFB_1_internal_pwm_STATUS_MASK_PTR       ((reg8 *) PSFB_1_internal_pwm_PWMUDB_sSTSReg_rstSts_stsreg__MASK_REG)
    #define PSFB_1_internal_pwm_STATUS_AUX_CTRL       (*(reg8 *) PSFB_1_internal_pwm_PWMUDB_sSTSReg_rstSts_stsreg__STATUS_AUX_CTL_REG)
    #define PSFB_1_internal_pwm_CONTROL               (*(reg8 *) PSFB_1_internal_pwm_PWMUDB_sCTRLReg_SyncCtl_ctrlreg__CONTROL_REG)
    #define PSFB_1_internal_pwm_CONTROL_PTR           ((reg8 *) PSFB_1_internal_pwm_PWMUDB_sCTRLReg_SyncCtl_ctrlreg__CONTROL_REG)
    
    
    /***********************************
    *          Constants
    ***********************************/

    /* Control Register definitions */
    #define PSFB_1_internal_pwm_CTRL_ENABLE_SHIFT      0x07u
    #define PSFB_1_internal_pwm_CTRL_RESET_SHIFT       0x06u
    #define PSFB_1_internal_pwm_CTRL_CMPMODE2_SHIFT    0x03u
    #define PSFB_1_internal_pwm_CTRL_CMPMODE1_SHIFT    0x00u
    #define PSFB_1_internal_pwm_CTRL_DEAD_TIME_SHIFT   0x00u   /* No Shift Needed for UDB block */
    /* Control Register Bit Masks */
    #define PSFB_1_internal_pwm_CTRL_ENABLE            (uint8)((uint8)0x01u << PSFB_1_internal_pwm_CTRL_ENABLE_SHIFT)
    #define PSFB_1_internal_pwm_CTRL_RESET             (uint8)((uint8)0x01u << PSFB_1_internal_pwm_CTRL_RESET_SHIFT)
    #define PSFB_1_internal_pwm_CTRL_CMPMODE2_MASK     (uint8)((uint8)0x07u << PSFB_1_internal_pwm_CTRL_CMPMODE2_SHIFT)
    #define PSFB_1_internal_pwm_CTRL_CMPMODE1_MASK     (uint8)((uint8)0x07u << PSFB_1_internal_pwm_CTRL_CMPMODE1_SHIFT) 
    
    /* Status Register Bit Locations */
    #define PSFB_1_internal_pwm_STATUS_KILL_SHIFT          0x05u
    #define PSFB_1_internal_pwm_STATUS_FIFONEMPTY_SHIFT    0x04u
    #define PSFB_1_internal_pwm_STATUS_FIFOFULL_SHIFT      0x03u  
    #define PSFB_1_internal_pwm_STATUS_TC_SHIFT            0x02u
    #define PSFB_1_internal_pwm_STATUS_CMP2_SHIFT          0x01u
    #define PSFB_1_internal_pwm_STATUS_CMP1_SHIFT          0x00u
    /* Status Register Interrupt Enable Bit Locations - UDB Status Interrupt Mask match Status Bit Locations*/
    #define PSFB_1_internal_pwm_STATUS_KILL_INT_EN_MASK_SHIFT          PSFB_1_internal_pwm_STATUS_KILL_SHIFT          
    #define PSFB_1_internal_pwm_STATUS_FIFONEMPTY_INT_EN_MASK_SHIFT    PSFB_1_internal_pwm_STATUS_FIFONEMPTY_SHIFT    
    #define PSFB_1_internal_pwm_STATUS_FIFOFULL_INT_EN_MASK_SHIFT      PSFB_1_internal_pwm_STATUS_FIFOFULL_SHIFT        
    #define PSFB_1_internal_pwm_STATUS_TC_INT_EN_MASK_SHIFT            PSFB_1_internal_pwm_STATUS_TC_SHIFT            
    #define PSFB_1_internal_pwm_STATUS_CMP2_INT_EN_MASK_SHIFT          PSFB_1_internal_pwm_STATUS_CMP2_SHIFT          
    #define PSFB_1_internal_pwm_STATUS_CMP1_INT_EN_MASK_SHIFT          PSFB_1_internal_pwm_STATUS_CMP1_SHIFT   
    /* Status Register Bit Masks */
    #define PSFB_1_internal_pwm_STATUS_KILL            (uint8)((uint8)0x00u << PSFB_1_internal_pwm_STATUS_KILL_SHIFT )
    #define PSFB_1_internal_pwm_STATUS_FIFOFULL        (uint8)((uint8)0x01u << PSFB_1_internal_pwm_STATUS_FIFOFULL_SHIFT)
    #define PSFB_1_internal_pwm_STATUS_FIFONEMPTY      (uint8)((uint8)0x01u << PSFB_1_internal_pwm_STATUS_FIFONEMPTY_SHIFT)
    #define PSFB_1_internal_pwm_STATUS_TC              (uint8)((uint8)0x01u << PSFB_1_internal_pwm_STATUS_TC_SHIFT)
    #define PSFB_1_internal_pwm_STATUS_CMP2            (uint8)((uint8)0x01u << PSFB_1_internal_pwm_STATUS_CMP2_SHIFT) 
    #define PSFB_1_internal_pwm_STATUS_CMP1            (uint8)((uint8)0x01u << PSFB_1_internal_pwm_STATUS_CMP1_SHIFT)
    /* Status Register Interrupt Bit Masks  - UDB Status Interrupt Mask match Status Bit Locations */
    #define PSFB_1_internal_pwm_STATUS_KILL_INT_EN_MASK            PSFB_1_internal_pwm_STATUS_KILL
    #define PSFB_1_internal_pwm_STATUS_FIFOFULL_INT_EN_MASK        PSFB_1_internal_pwm_STATUS_FIFOFULL
    #define PSFB_1_internal_pwm_STATUS_FIFONEMPTY_INT_EN_MASK      PSFB_1_internal_pwm_STATUS_FIFONEMPTY
    #define PSFB_1_internal_pwm_STATUS_TC_INT_EN_MASK              PSFB_1_internal_pwm_STATUS_TC
    #define PSFB_1_internal_pwm_STATUS_CMP2_INT_EN_MASK            PSFB_1_internal_pwm_STATUS_CMP2
    #define PSFB_1_internal_pwm_STATUS_CMP1_INT_EN_MASK            PSFB_1_internal_pwm_STATUS_CMP1
                                                          
    /* Datapath Auxillary Control Register definitions */
    #define PSFB_1_internal_pwm_AUX_CTRL_FIFO0_CLR     0x01u
    #define PSFB_1_internal_pwm_AUX_CTRL_FIFO1_CLR     0x02u
    #define PSFB_1_internal_pwm_AUX_CTRL_FIFO0_LVL     0x04u
    #define PSFB_1_internal_pwm_AUX_CTRL_FIFO1_LVL     0x08u
    #define PSFB_1_internal_pwm_STATUS_ACTL_INT_EN_MASK  0x10u /* As defined for the ACTL Register */
#endif /* PSFB_1_internal_pwm_UsingFixedFunction */

#endif  /* CY_PWM_PSFB_1_internal_pwm_H */


/* [] END OF FILE */
