/*******************************************************************************
* File Name: PSFB_1_internal_pwm_PM.c
* Version 2.40
*
* Description:
*  This file provides the power management source code to API for the
*  PWM.
*
* Note:
*
********************************************************************************
* Copyright 2008-2012, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions,
* disclaimers, and limitations in the end user license agreement accompanying
* the software package with which this file was provided.
*******************************************************************************/
#include "cytypes.h"
#include "PSFB_1_internal_pwm.h"

static PSFB_1_internal_pwm_backupStruct PSFB_1_internal_pwm_backup;


/*******************************************************************************
* Function Name: PSFB_1_internal_pwm_SaveConfig
********************************************************************************
*
* Summary:
*  Saves the current user configuration of the component.
*  
* Parameters:  
*  None
*
* Return: 
*  None
*
* Global variables:
*  PSFB_1_internal_pwm_backup:  Variables of this global structure are modified to 
*  store the values of non retention configuration registers when Sleep() API is 
*  called.
*
*******************************************************************************/
void PSFB_1_internal_pwm_SaveConfig(void) 
{
    
    #if(!PSFB_1_internal_pwm_UsingFixedFunction)
        #if (CY_UDB_V0)
            PSFB_1_internal_pwm_backup.PWMUdb = PSFB_1_internal_pwm_ReadCounter();
            PSFB_1_internal_pwm_backup.PWMPeriod = PSFB_1_internal_pwm_ReadPeriod();
            #if (PSFB_1_internal_pwm_UseStatus)
                PSFB_1_internal_pwm_backup.InterruptMaskValue = PSFB_1_internal_pwm_STATUS_MASK;
            #endif /* (PSFB_1_internal_pwm_UseStatus) */
            
            #if(PSFB_1_internal_pwm_UseOneCompareMode)
                PSFB_1_internal_pwm_backup.PWMCompareValue = PSFB_1_internal_pwm_ReadCompare();
            #else
                PSFB_1_internal_pwm_backup.PWMCompareValue1 = PSFB_1_internal_pwm_ReadCompare1();
                PSFB_1_internal_pwm_backup.PWMCompareValue2 = PSFB_1_internal_pwm_ReadCompare2();
            #endif /* (PSFB_1_internal_pwm_UseOneCompareMode) */
            
           #if(PSFB_1_internal_pwm_DeadBandUsed)
                PSFB_1_internal_pwm_backup.PWMdeadBandValue = PSFB_1_internal_pwm_ReadDeadTime();
            #endif /* (PSFB_1_internal_pwm_DeadBandUsed) */
          
            #if ( PSFB_1_internal_pwm_KillModeMinTime)
                PSFB_1_internal_pwm_backup.PWMKillCounterPeriod = PSFB_1_internal_pwm_ReadKillTime();
            #endif /* ( PSFB_1_internal_pwm_KillModeMinTime) */
        #endif /* (CY_UDB_V0) */
        
        #if (CY_UDB_V1)
            #if(!PSFB_1_internal_pwm_PWMModeIsCenterAligned)
                PSFB_1_internal_pwm_backup.PWMPeriod = PSFB_1_internal_pwm_ReadPeriod();
            #endif /* (!PSFB_1_internal_pwm_PWMModeIsCenterAligned) */
            PSFB_1_internal_pwm_backup.PWMUdb = PSFB_1_internal_pwm_ReadCounter();
            #if (PSFB_1_internal_pwm_UseStatus)
                PSFB_1_internal_pwm_backup.InterruptMaskValue = PSFB_1_internal_pwm_STATUS_MASK;
            #endif /* (PSFB_1_internal_pwm_UseStatus) */
            
            #if(PSFB_1_internal_pwm_DeadBandMode == PSFB_1_internal_pwm__B_PWM__DBM_256_CLOCKS || \
                PSFB_1_internal_pwm_DeadBandMode == PSFB_1_internal_pwm__B_PWM__DBM_2_4_CLOCKS)
                PSFB_1_internal_pwm_backup.PWMdeadBandValue = PSFB_1_internal_pwm_ReadDeadTime();
            #endif /*  deadband count is either 2-4 clocks or 256 clocks */
            
            #if(PSFB_1_internal_pwm_KillModeMinTime)
                 PSFB_1_internal_pwm_backup.PWMKillCounterPeriod = PSFB_1_internal_pwm_ReadKillTime();
            #endif /* (PSFB_1_internal_pwm_KillModeMinTime) */
        #endif /* (CY_UDB_V1) */
        
        #if(PSFB_1_internal_pwm_UseControl)
            PSFB_1_internal_pwm_backup.PWMControlRegister = PSFB_1_internal_pwm_ReadControlRegister();
        #endif /* (PSFB_1_internal_pwm_UseControl) */
    #endif  /* (!PSFB_1_internal_pwm_UsingFixedFunction) */
}


/*******************************************************************************
* Function Name: PSFB_1_internal_pwm_RestoreConfig
********************************************************************************
* 
* Summary:
*  Restores the current user configuration of the component.
*
* Parameters:  
*  None
*
* Return: 
*  None
*
* Global variables:
*  PSFB_1_internal_pwm_backup:  Variables of this global structure are used to  
*  restore the values of non retention registers on wakeup from sleep mode.
*
*******************************************************************************/
void PSFB_1_internal_pwm_RestoreConfig(void) 
{
        #if(!PSFB_1_internal_pwm_UsingFixedFunction)
            #if (CY_UDB_V0)
                /* Interrupt State Backup for Critical Region*/
                uint8 PSFB_1_internal_pwm_interruptState;
                /* Enter Critical Region*/
                PSFB_1_internal_pwm_interruptState = CyEnterCriticalSection();
                #if (PSFB_1_internal_pwm_UseStatus)
                    /* Use the interrupt output of the status register for IRQ output */
                    PSFB_1_internal_pwm_STATUS_AUX_CTRL |= PSFB_1_internal_pwm_STATUS_ACTL_INT_EN_MASK;
                    
                    PSFB_1_internal_pwm_STATUS_MASK = PSFB_1_internal_pwm_backup.InterruptMaskValue;
                #endif /* (PSFB_1_internal_pwm_UseStatus) */
                
                #if (PSFB_1_internal_pwm_Resolution == 8)
                    /* Set FIFO 0 to 1 byte register for period*/
                    PSFB_1_internal_pwm_AUX_CONTROLDP0 |= (PSFB_1_internal_pwm_AUX_CTRL_FIFO0_CLR);
                #else /* (PSFB_1_internal_pwm_Resolution == 16)*/
                    /* Set FIFO 0 to 1 byte register for period */
                    PSFB_1_internal_pwm_AUX_CONTROLDP0 |= (PSFB_1_internal_pwm_AUX_CTRL_FIFO0_CLR);
                    PSFB_1_internal_pwm_AUX_CONTROLDP1 |= (PSFB_1_internal_pwm_AUX_CTRL_FIFO0_CLR);
                #endif /* (PSFB_1_internal_pwm_Resolution == 8) */
                /* Exit Critical Region*/
                CyExitCriticalSection(PSFB_1_internal_pwm_interruptState);
                
                PSFB_1_internal_pwm_WriteCounter(PSFB_1_internal_pwm_backup.PWMUdb);
                PSFB_1_internal_pwm_WritePeriod(PSFB_1_internal_pwm_backup.PWMPeriod);
                
                #if(PSFB_1_internal_pwm_UseOneCompareMode)
                    PSFB_1_internal_pwm_WriteCompare(PSFB_1_internal_pwm_backup.PWMCompareValue);
                #else
                    PSFB_1_internal_pwm_WriteCompare1(PSFB_1_internal_pwm_backup.PWMCompareValue1);
                    PSFB_1_internal_pwm_WriteCompare2(PSFB_1_internal_pwm_backup.PWMCompareValue2);
                #endif /* (PSFB_1_internal_pwm_UseOneCompareMode) */
                
               #if(PSFB_1_internal_pwm_DeadBandMode == PSFB_1_internal_pwm__B_PWM__DBM_256_CLOCKS || \
                   PSFB_1_internal_pwm_DeadBandMode == PSFB_1_internal_pwm__B_PWM__DBM_2_4_CLOCKS)
                    PSFB_1_internal_pwm_WriteDeadTime(PSFB_1_internal_pwm_backup.PWMdeadBandValue);
                #endif /* deadband count is either 2-4 clocks or 256 clocks */
            
                #if ( PSFB_1_internal_pwm_KillModeMinTime)
                    PSFB_1_internal_pwm_WriteKillTime(PSFB_1_internal_pwm_backup.PWMKillCounterPeriod);
                #endif /* ( PSFB_1_internal_pwm_KillModeMinTime) */
            #endif /* (CY_UDB_V0) */
            
            #if (CY_UDB_V1)
                #if(!PSFB_1_internal_pwm_PWMModeIsCenterAligned)
                    PSFB_1_internal_pwm_WritePeriod(PSFB_1_internal_pwm_backup.PWMPeriod);
                #endif /* (!PSFB_1_internal_pwm_PWMModeIsCenterAligned) */
                PSFB_1_internal_pwm_WriteCounter(PSFB_1_internal_pwm_backup.PWMUdb);
                #if (PSFB_1_internal_pwm_UseStatus)
                    PSFB_1_internal_pwm_STATUS_MASK = PSFB_1_internal_pwm_backup.InterruptMaskValue;
                #endif /* (PSFB_1_internal_pwm_UseStatus) */
                
                #if(PSFB_1_internal_pwm_DeadBandMode == PSFB_1_internal_pwm__B_PWM__DBM_256_CLOCKS || \
                    PSFB_1_internal_pwm_DeadBandMode == PSFB_1_internal_pwm__B_PWM__DBM_2_4_CLOCKS)
                    PSFB_1_internal_pwm_WriteDeadTime(PSFB_1_internal_pwm_backup.PWMdeadBandValue);
                #endif /* deadband count is either 2-4 clocks or 256 clocks */
                
                #if(PSFB_1_internal_pwm_KillModeMinTime)
                    PSFB_1_internal_pwm_WriteKillTime(PSFB_1_internal_pwm_backup.PWMKillCounterPeriod);
                #endif /* (PSFB_1_internal_pwm_KillModeMinTime) */
            #endif /* (CY_UDB_V1) */
            
            #if(PSFB_1_internal_pwm_UseControl)
                PSFB_1_internal_pwm_WriteControlRegister(PSFB_1_internal_pwm_backup.PWMControlRegister); 
            #endif /* (PSFB_1_internal_pwm_UseControl) */
        #endif  /* (!PSFB_1_internal_pwm_UsingFixedFunction) */
    }


/*******************************************************************************
* Function Name: PSFB_1_internal_pwm_Sleep
********************************************************************************
* 
* Summary:
*  Disables block's operation and saves the user configuration. Should be called 
*  just prior to entering sleep.
*  
* Parameters:  
*  None
*
* Return: 
*  None
*
* Global variables:
*  PSFB_1_internal_pwm_backup.PWMEnableState:  Is modified depending on the enable 
*  state of the block before entering sleep mode.
*
*******************************************************************************/
void PSFB_1_internal_pwm_Sleep(void) 
{
    #if(PSFB_1_internal_pwm_UseControl)
        if(PSFB_1_internal_pwm_CTRL_ENABLE == (PSFB_1_internal_pwm_CONTROL & PSFB_1_internal_pwm_CTRL_ENABLE))
        {
            /*Component is enabled */
            PSFB_1_internal_pwm_backup.PWMEnableState = 1u;
        }
        else
        {
            /* Component is disabled */
            PSFB_1_internal_pwm_backup.PWMEnableState = 0u;
        }
    #endif /* (PSFB_1_internal_pwm_UseControl) */

    /* Stop component */
    PSFB_1_internal_pwm_Stop();
    
    /* Save registers configuration */
    PSFB_1_internal_pwm_SaveConfig();
}


/*******************************************************************************
* Function Name: PSFB_1_internal_pwm_Wakeup
********************************************************************************
* 
* Summary:
*  Restores and enables the user configuration. Should be called just after 
*  awaking from sleep.
*  
* Parameters:  
*  None
*
* Return: 
*  None
*
* Global variables:
*  PSFB_1_internal_pwm_backup.pwmEnable:  Is used to restore the enable state of 
*  block on wakeup from sleep mode.
*
*******************************************************************************/
void PSFB_1_internal_pwm_Wakeup(void) 
{
     /* Restore registers values */
    PSFB_1_internal_pwm_RestoreConfig();
    
    if(PSFB_1_internal_pwm_backup.PWMEnableState != 0u)
    {
        /* Enable component's operation */
        PSFB_1_internal_pwm_Enable();
    } /* Do nothing if component's block was disabled before */
    
}


/* [] END OF FILE */
